@@ -72,6 +72,7 @@ struct GpmBacklightPrivate
 	GTimer			*idle_timer;
 	guint			 idle_dim_timeout;
 	guint			 master_percentage;
+	GDBusProxy		*proxy;
 };
 
 enum {
@@ -166,6 +167,97 @@ gpm_backlight_set_brightness (GpmBacklight *backlight, guint percentage, GError
 	return ret;
 }
 
+static void
+gpm_backlight_brightness_interact_panel (GpmBacklight *backlight, gint *x, gint *y, gint w, gint h, gint startx, gint starty)
+{
+        GVariant *position;
+	GVariant *res;
+        GVariant *height;
+        gint pos;
+        gint ht;
+        GError *error = NULL;
+        position = g_dbus_proxy_call_sync (backlight->priv->proxy, "GetPanelPosition",g_variant_new("(s)","position"),G_DBUS_CALL_FLAGS_NONE,-1,NULL,&error);
+	if(position == NULL)
+	{
+		if(error != NULL)
+			g_error_free (error);
+		*x = startx + w/100;
+                *y = starty + h*4/100;
+                return;
+	}
+	else
+	{
+		g_variant_get (position, "(i)", &pos);
+		g_variant_unref (position);
+	}
+        /*res = g_dbus_proxy_call_sync (backlight->priv->proxy, "GetPanelPosition",g_variant_new("(s)","position"),G_DBUS_CALL_FLAGS_NONE,-1,NULL,&error);
+        if(error == NULL && res != NULL)
+	{
+		g_variant_get(res,"(i)",&pos);
+                g_variant_unref (res);
+                g_variant_unref (position);
+        }
+	else if(error != NULL)
+	{
+		g_message("failed to get position");
+		g_error_free (error);
+		*x = startx + w/100;
+                *y = starty + h*4/100;
+		return;
+	}
+
+        height = g_dbus_proxy_call_sync (backlight->priv->proxy, "GetPanelHeight",NULL,G_DBUS_CALL_FLAGS_NONE,-1,NULL,&error);
+        if(height == NULL)
+        {
+                g_message("failed to get height");
+                g_error_free (error);
+                g_variant_unref (position);
+                *x = startx + w/100;
+                *y = starty + h*4/100;
+                return;
+        }
+        g_variant_get (position, "(i)", &pos);
+
+        g_variant_unref (position);
+        g_variant_unref (height);*/
+
+        switch (pos)
+        {
+        case 0:
+        {
+                *x = startx + w/100;
+                *y = starty + h*4/100;
+                break;
+        }
+        case 1:
+        {
+                *x = startx + w/100;
+                *y = starty + h*96/100 - 300;
+                break;
+        }
+        case 2:
+        {
+                *x = startx + w*99/100 - 64;
+                *y = starty + h*4/100;
+                break;
+        }
+        case 3:
+        {
+                *x = startx + w/100;
+                *y = starty + h*4/100;
+                break;
+        }
+        default:
+        {
+                *x = startx + w/100;
+                *y = starty + h*4/100;
+                break;
+        }
+
+        }
+        return;
+}
+                                                                                                                                                                                                 
 /**
  * gpm_backlight_dialog_init:
  *
@@ -217,6 +309,14 @@ gpm_backlight_dialog_show (GpmBacklight *backlight)
         GdkDeviceManager *device_manager;
         GdkDevice     *device;
 
+	GtkStyleContext *context = gtk_widget_get_style_context (GTK_WIDGET (backlight->priv->popup));
+        gtk_style_context_save (context);
+        GtkCssProvider *provider = gtk_css_provider_new ();
+        gtk_css_provider_load_from_data(provider,".volume-box {border-radius:6px;background:rgba(0,0,0,0.55);}",-1,NULL);
+        gtk_style_context_add_provider (context,GTK_STYLE_PROVIDER(provider),GTK_STYLE_PROVIDER_PRIORITY_USER);
+        gtk_style_context_add_class(context,"volume-box");
+
+	g_object_unref (provider);
 	/*
 	 * get the window size
 	 * if the window hasn't been mapped, it doesn't necessarily
@@ -260,9 +360,14 @@ gpm_backlight_dialog_show (GpmBacklight *backlight)
 	screen_w = geometry.width;
 	screen_h = geometry.height;
 
-	x = ((screen_w - orig_w) / 2) + geometry.x;
-	y = geometry.y + (screen_h / 2) + (screen_h / 2 - orig_h) / 2;
-
+	//x = ((screen_w - orig_w) / 2) + geometry.x;
+	//y = geometry.y + (screen_h / 2) + (screen_h / 2 - orig_h) / 2;
+	if (backlight->priv->proxy == NULL){
+		x = geometry.x + screen_w / 100;
+		y = geometry.y + (screen_h * 4) / 100;
+	}
+	else
+		gpm_backlight_brightness_interact_panel(backlight,&x,&y,screen_w,screen_h,geometry.x,geometry.y);
 	gtk_window_move (GTK_WINDOW (backlight->priv->popup), x, y);
 
 	gtk_widget_show (backlight->priv->popup);
@@ -324,6 +429,7 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	if (use_initial) {
 		egg_debug ("Setting initial brightness level");
 		battery_reduce = g_settings_get_boolean (backlight->priv->settings, GPM_SETTINGS_BACKLIGHT_BATTERY_REDUCE);
+        	battery_reduce = FALSE;
 		if (on_battery && battery_reduce) {
 			value = g_settings_get_int (backlight->priv->settings, GPM_SETTINGS_BRIGHTNESS_DIM_BATT);
 			if (value > 100) {
@@ -400,7 +506,7 @@ gpm_settings_key_changed_cb (GSettings *settings, const gchar *key, GpmBacklight
 
 	if (g_strcmp0 (key, GPM_SETTINGS_BRIGHTNESS_AC) == 0) {
 		backlight->priv->master_percentage = g_settings_get_double (settings, key);
-		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE, TRUE);
+        gpm_backlight_brightness_evaluate_and_set (backlight, FALSE, TRUE);
 
 	} else if (on_battery && g_strcmp0 (key, GPM_SETTINGS_BRIGHTNESS_DIM_BATT) == 0) {
 		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE, TRUE);
@@ -467,13 +573,16 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 			gpm_backlight_dialog_show (backlight);
 			/* save the new percentage */
 			backlight->priv->master_percentage = percentage;
+            egg_debug ("saving brightness for ac supply: %i", percentage);
+            g_settings_set_double (backlight->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC,
+                           percentage*1.0);
 			/* if using AC power supply, save the new brightness settings */
-			g_object_get (backlight->priv->client, "on-battery", &on_battery, NULL);
-			if (!on_battery) {
-				egg_debug ("saving brightness for ac supply: %i", percentage);
-				g_settings_set_double (backlight->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC,
-						       percentage*1.0);
-			}
+//			g_object_get (backlight->priv->client, "on-battery", &on_battery, NULL);
+//			if (!on_battery) {
+//				egg_debug ("saving brightness for ac supply: %i", percentage);
+//				g_settings_set_double (backlight->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC,
+//						       percentage*1.0);
+//			}
 		}
 		/* we emit a signal for the brightness applet */
 		if (ret && hw_changed) {
@@ -493,13 +602,16 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 			gpm_backlight_dialog_show (backlight);
 			/* save the new percentage */
 			backlight->priv->master_percentage = percentage;
+            egg_debug ("saving brightness for ac supply: %i", percentage);
+            g_settings_set_double (backlight->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC,
+                           percentage*1.0);
 			/* if using AC power supply, save the new brightness settings */
-			g_object_get (backlight->priv->client, "on-battery", &on_battery, NULL);
-			if (!on_battery) {
-				egg_debug ("saving brightness for ac supply: %i", percentage);
-				g_settings_set_double (backlight->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC,
-						       percentage*1.0);
-			}
+//			g_object_get (backlight->priv->client, "on-battery", &on_battery, NULL);
+//			if (!on_battery) {
+//				egg_debug ("saving brightness for ac supply: %i", percentage);
+//				g_settings_set_double (backlight->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC,
+//						       percentage*1.0);
+//			}
 		}
 		/* we emit a signal for the brightness applet */
 		if (ret && hw_changed) {
@@ -539,26 +651,24 @@ gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_i
 
 	if (is_idle == FALSE) {
 		egg_debug ("we have just been idle for %lfs", elapsed);
-
+		gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 		/* The user immediatly undimmed the screen!
 		 * We should double the timeout to avoid this happening again */
-		if (elapsed < 10) {
-			/* double the event time */
+		/*if (elapsed < 10) {
 			backlight->priv->idle_dim_timeout *= 2.0;
 			egg_debug ("increasing idle dim time to %is", backlight->priv->idle_dim_timeout);
 			gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
-		}
+		}*/
 
 		/* We reset the dimming after 2 minutes of idle,
 		 * as the user will have changed tasks */
-		if (elapsed > 2*60) {
-			/* reset back to our default dimming */
+		/*if (elapsed > 2*60) {
 			backlight->priv->idle_dim_timeout =
 				g_settings_get_int (backlight->priv->settings,
 					   GPM_SETTINGS_IDLE_DIM_TIME);
 			egg_debug ("resetting idle dim time to %is", backlight->priv->idle_dim_timeout);
 			gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
-		}
+		}*/
 	} else {
 		egg_debug ("we were active for %lfs", elapsed);
 	}
@@ -715,7 +825,8 @@ gpm_backlight_finalize (GObject *object)
 	g_object_unref (backlight->priv->idle);
 	g_object_unref (backlight->priv->brightness);
         //g_object_unref (backlight->priv->console);
-
+	if (backlight->priv->proxy != NULL)
+		g_object_unref (backlight->priv->proxy);
 	g_return_if_fail (backlight->priv != NULL);
 	G_OBJECT_CLASS (gpm_backlight_parent_class)->finalize (object);
 }
@@ -782,7 +893,8 @@ gpm_backlight_init (GpmBacklight *backlight)
 	/* set the main brightness, this is designed to be updated if the user changes the
 	 * brightness so we can undim to the 'correct' value */
 	backlight->priv->master_percentage = g_settings_get_double (backlight->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC);
-
+    if(backlight->priv->master_percentage <= 1)
+        backlight->priv->master_percentage = 1;
 	/* watch for brightness up and down buttons and also check lid state */
 	backlight->priv->button = gpm_button_new ();
 	g_signal_connect (backlight->priv->button, "button-pressed",
@@ -800,8 +912,9 @@ gpm_backlight_init (GpmBacklight *backlight)
 
 	/* use a visual widget */
 	backlight->priv->popup = msd_media_keys_window_new ();
+	/*brightness icon---jh*/
 	msd_media_keys_window_set_action_custom (MSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
-						 "gpm-brightness-lcd",
+						 "display-brightness-symbolic",
 						 TRUE);
         gtk_window_set_position (GTK_WINDOW (backlight->priv->popup), GTK_WIN_POS_NONE);
 
@@ -818,6 +931,23 @@ gpm_backlight_init (GpmBacklight *backlight)
 
 	/* sync at startup */
 	gpm_backlight_brightness_evaluate_and_set (backlight, FALSE, TRUE);
+
+	GError *error = NULL;
+	//different from qdbus
+	backlight->priv->proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+					       NULL,
+					       "com.ukui.panel.desktop",
+					       "/",
+					       "com.ukui.panel.desktop",					       
+					       NULL,
+					       &error );
+	if(backlight->priv->proxy == NULL)
+	{
+		if(error != NULL){
+			egg_debug ("error connecting to dbus - %s",error->message);
+			g_error_free (error);
+		}
+	}
 }
 
 /**
