@@ -568,14 +568,15 @@ gpm_engine_settings_key_changed_cb (GSettings *settings, const gchar *key, GpmEn
 	if (g_strcmp0 (key, GPM_SETTINGS_USE_TIME_POLICY) == 0) {
 		engine->priv->use_time_primary = g_settings_get_boolean (settings, key);
 
-	} else if (g_strcmp0 (key, GPM_SETTINGS_ICON_POLICY) == 0) {
+	} 
+	//else if (g_strcmp0 (key, GPM_SETTINGS_ICON_POLICY) == 0) {
 
 		/* do we want to display the icon in the tray */
-		engine->priv->icon_policy = g_settings_get_enum (settings, key);
+	//	engine->priv->icon_policy = g_settings_get_enum (settings, key);
 
 		/* perhaps change icon */
-		gpm_engine_recalculate_state_icon (engine);
-	}
+	//	gpm_engine_recalculate_state_icon (engine);
+	//}
 }
 
 /**
@@ -877,7 +878,7 @@ gpm_engine_coldplug_idle_cb (GpmEngine *engine)
 	}
 #endif
 	/* connected mobile phones */
-	gpm_phone_coldplug (engine->priv->phone);
+	//gpm_phone_coldplug (engine->priv->phone);
 
 	gpm_engine_recalculate_state (engine);
 
@@ -1021,7 +1022,7 @@ gpm_engine_device_changed_cb (UpClient *client, UpDevice *device, GpmEngine *eng
 	warning = gpm_engine_get_warning (engine, device);
 
         //kobe
-        if (GPM_ENGINE_FIRST_START){
+        /*if (GPM_ENGINE_FIRST_START){
             GPM_ENGINE_FIRST_START = FALSE;
             if (warning == GPM_ENGINE_WARNING_LOW) {
                 egg_debug ("** EMIT: charge-low");
@@ -1033,7 +1034,6 @@ gpm_engine_device_changed_cb (UpClient *client, UpDevice *device, GpmEngine *eng
                 egg_debug ("** EMIT: charge-action");
                 g_signal_emit (engine, signals [CHARGE_ACTION], 0, device);
             }
-            //save new state
             g_object_set_data (G_OBJECT(device), "engine-warning-old", GUINT_TO_POINTER(warning));
         }
         else {
@@ -1048,7 +1048,6 @@ gpm_engine_device_changed_cb (UpClient *client, UpDevice *device, GpmEngine *eng
                     egg_debug ("** EMIT: charge-action");
                     g_signal_emit (engine, signals [CHARGE_ACTION], 0, device);
                 }
-                //save new state
                 g_object_set_data (G_OBJECT(device), "engine-warning-old", GUINT_TO_POINTER(warning));
             }
             else {
@@ -1059,8 +1058,8 @@ gpm_engine_device_changed_cb (UpClient *client, UpDevice *device, GpmEngine *eng
                     g_signal_emit (engine, signals [CHARGE_CRITICAL_NOTIFY], 0, device);
                 }
             }
-        }
-        /*if (warning != warning_old) {
+        }*/
+        if (warning != warning_old) {
 		if (warning == GPM_ENGINE_WARNING_LOW) {
 			egg_debug ("** EMIT: charge-low");
 			g_signal_emit (engine, signals [CHARGE_LOW], 0, device);
@@ -1073,14 +1072,14 @@ gpm_engine_device_changed_cb (UpClient *client, UpDevice *device, GpmEngine *eng
 		}
                 //save new state
 		g_object_set_data (G_OBJECT(device), "engine-warning-old", GUINT_TO_POINTER(warning));
-        }*/
+        }
 	//jiangh
-	static gboolean notice_once = TRUE;
+	/*static gboolean notice_once = TRUE;
 	if ( (TimeToFull == 0) && (notice_once) && (percentage < 3.0) )
 	{
 		g_signal_emit_by_name(engine,"close-notify");
 		notice_once = FALSE;
-	}
+	}*/
 	gpm_engine_recalculate_state (engine);
 }
 
@@ -1221,9 +1220,9 @@ phone_device_refresh_cb (GpmPhone *phone, guint idx, GpmEngine *engine)
 			      NULL);
 
 		if (kind == UP_DEVICE_KIND_PHONE) {
-			is_present = gpm_phone_get_present (phone, idx);
-			state = gpm_phone_get_on_ac (phone, idx) ? UP_DEVICE_STATE_CHARGING : UP_DEVICE_STATE_DISCHARGING;
-			percentage = gpm_phone_get_percentage (phone, idx);
+			//is_present = gpm_phone_get_present (phone, idx);
+			//state = gpm_phone_get_on_ac (phone, idx) ? UP_DEVICE_STATE_CHARGING : UP_DEVICE_STATE_DISCHARGING;
+			//percentage = gpm_phone_get_percentage (phone, idx);
 			break;
 		}
 	}
@@ -1261,13 +1260,13 @@ gpm_engine_init (GpmEngine *engine)
 	g_signal_connect (engine->priv->settings, "changed",
 			  G_CALLBACK (gpm_engine_settings_key_changed_cb), engine);
 
-	engine->priv->phone = gpm_phone_new ();
+	/*engine->priv->phone = gpm_phone_new ();
 	g_signal_connect (engine->priv->phone, "device-added",
 			  G_CALLBACK (phone_device_added_cb), engine);
 	g_signal_connect (engine->priv->phone, "device-removed",
 			  G_CALLBACK (phone_device_removed_cb), engine);
 	g_signal_connect (engine->priv->phone, "device-refresh",
-			  G_CALLBACK (phone_device_refresh_cb), engine);
+			  G_CALLBACK (phone_device_refresh_cb), engine);*/
 
 	/* create a fake virtual composite battery */
 #if UP_CHECK_VERSION(0, 99, 0)
@@ -1289,7 +1288,7 @@ gpm_engine_init (GpmEngine *engine)
 	engine->priv->previous_summary = NULL;
 
 	/* do we want to display the icon in the tray */
-	engine->priv->icon_policy = g_settings_get_enum (engine->priv->settings, GPM_SETTINGS_ICON_POLICY);
+	engine->priv->icon_policy = GPM_ICON_POLICY_NEVER;//g_settings_get_enum (engine->priv->settings, GPM_SETTINGS_ICON_POLICY);
 
 	/* get percentage policy */
 	engine->priv->low_percentage = g_settings_get_int (engine->priv->settings, GPM_SETTINGS_PERCENTAGE_LOW);
