@@ -64,7 +64,7 @@ struct GpmTrayIconPrivate
 	GtkStatusIcon		*status_icon;
 	gboolean		 show_actions;
         GtkWidget               *main_window;//kobe
-        GSettings               *panel_settings;//kobe
+        //GSettings               *panel_settings;//kobe
 };
 
 G_DEFINE_TYPE (GpmTrayIcon, gpm_tray_icon, G_TYPE_OBJECT)
@@ -134,7 +134,7 @@ gpm_tray_icon_set_icon (GpmTrayIcon *icon, const gchar *icon_name)
 		                                    icon_name);
 
 		/* make sure that we are visible */
-		gpm_tray_icon_show (icon, TRUE);
+		gpm_tray_icon_show (icon, FALSE);
 	} else {
 		/* remove icon */
 		egg_debug ("no icon will be displayed");
@@ -192,6 +192,58 @@ gpm_tray_icon_show_preferences_cb (GtkMenuItem *item, gpointer data)
 		egg_warning ("Couldn't execute command: %s", command);
 }
 
+//jiangh powerpolicy
+static gboolean
+gpm_tray_icon_power_policy (gint mode) {
+    GError *error = NULL;
+    GDBusProxy *proxy;
+    GVariant *res = NULL;
+
+    egg_debug ("Requesting power policy");
+    proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
+                           G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+                           NULL,
+                           "ukui.power.policy",
+                           "/ukui/power/policy",
+                           "ukui.power.policy",
+                           NULL,
+                           &error );
+    //append all our arguments
+    if (proxy == NULL) {
+        egg_debug("Error connecting to dbus - %s", error->message);
+        g_error_free (error);
+        return FALSE;
+    }
+
+    res = g_dbus_proxy_call_sync (proxy, "control",
+                      g_variant_new( "(i)", mode),
+                      G_DBUS_CALL_FLAGS_NONE,
+                      -1,
+                      NULL,
+                      &error
+                      );
+    if (error != NULL) {
+        egg_debug ("Error in dbus - %s", error->message);
+        g_error_free (error);
+        return FALSE;
+    }
+
+    g_variant_unref(res);
+    return TRUE;
+}
+
+static void
+gpm_tray_icon_show_perf_cb (GtkMenuItem *item, gpointer data)
+{
+    gpm_tray_icon_power_policy(0);
+}
+
+static void
+gpm_tray_icon_show_save_cb (GtkMenuItem *item, gpointer data)
+{
+    gpm_tray_icon_power_policy(2);
+}
+
 /**
  * gpm_tray_icon_show_about_cb:
  * @action: A valid GtkAction
@@ -437,6 +489,71 @@ gpm_tray_icon_add_primary_device (GpmTrayIcon *icon, GtkMenu *menu, UpDevice *de
 	g_free (string);
 }
 
+static char* gpm_tray_caculate_theme (GtkWidget *widget)
+{
+    GdkColor color;
+    GtkStyle *style=gtk_rc_get_style(widget);
+    gtk_style_lookup_color (style,"panel_normal_bg_color",&color);
+
+    char color_hex[10]={0};
+    char color_hex_red[4]={0};
+    char color_hex_green[4]={0};
+    char color_hex_blue[4]={0};
+
+    if((color.red/257/16)==0){
+        sprintf(color_hex_red,"0%x",color.red/257);
+    } else {
+        sprintf(color_hex_red,"%x",color.red/257);
+    }
+    if((color.green/257)/16==0){
+        sprintf(color_hex_green,"0%x",color.green/257);
+    } else {
+        sprintf(color_hex_green,"%x",color.green/257);
+    }
+    if((color.blue/257)/16==0){
+        sprintf(color_hex_blue,"0%x",color.blue/257);
+    } else {
+        sprintf(color_hex_blue,"%x",color.blue/257);
+    }
+    sprintf(color_hex,"\#%s%s%s",color_hex_red,color_hex_green,color_hex_blue);
+//    g_message("colorhex:%s----------------",color_hex);
+    char *script =             "* {"
+                               "color: #f2f2f2;"
+                               "background-color: #283138;"
+                               "opacity: 0.8;"
+                               "}";
+    if (!strcmp (color_hex, "#283138")){
+        script =
+            "* {"
+            "color: #f2f2f2;"
+            "background-color: #283138;"
+            "opacity: 0.7;"
+            "}"
+            ;
+
+    }
+    else if(!strcmp (color_hex, "#f2f2f2"))
+    {
+        script =
+            "* {"
+            "color: #283138;"
+            "background-color: #f2f2f2;"
+            "opacity: 0.7;"
+            "}"
+            ;
+    }
+    return  script;
+}
+
+static gpm_tray_set_theme(GtkWidget *widget, const gchar *data)
+{
+    GtkCssProvider *provider = gtk_css_provider_new();
+    GtkStyleContext *context = gtk_widget_get_style_context(widget);
+    gtk_css_provider_load_from_data(provider,data,-1,NULL);
+    gtk_style_context_add_provider(context,GTK_STYLE_PROVIDER(provider),GTK_STYLE_PROVIDER_PRIORITY_USER);
+    g_object_unref(provider);
+}
+
 /**
  * gpm_tray_icon_create_menu:
  *
@@ -490,6 +607,18 @@ gpm_tray_icon_create_menu (GpmTrayIcon *icon)
 	g_signal_connect (G_OBJECT (item), "activate",
 			  G_CALLBACK (gpm_tray_icon_show_preferences_cb), icon);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+    /*powerpolicy*/
+    /*
+    item = gtk_image_menu_item_new_with_mnemonic (_("_Performance Mode"));
+    g_signal_connect (G_OBJECT (item), "activate",
+              G_CALLBACK (gpm_tray_icon_show_perf_cb), icon);
+    gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+    item = gtk_image_menu_item_new_with_mnemonic (_("_Save Mode"));
+    g_signal_connect (G_OBJECT (item), "activate",
+              G_CALLBACK (gpm_tray_icon_show_save_cb), icon);
+    gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+    */
 	
 	/*Set up custom panel menu theme support-gtk3 only */
 	GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET (menu));
@@ -509,6 +638,8 @@ gpm_tray_icon_create_menu (GpmTrayIcon *icon)
 			  G_CALLBACK (gpm_tray_icon_show_about_cb), icon);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
+    gchar *css = gpm_tray_caculate_theme(GTK_WIDGET (menu));
+   	gpm_tray_set_theme(GTK_WIDGET(menu),css);
 skip_prefs:
 	if (device != NULL)
 		g_object_unref (device);
@@ -866,7 +997,7 @@ gpm_tray_icon_init (GpmTrayIcon *icon)
 	icon->priv->engine = gpm_engine_new ();
 
         //kobe
-        icon->priv->panel_settings = g_settings_new_with_path ("org.ukui.panel.toplevel", "/org/ukui/panel/toplevels/bottom/");
+        //icon->priv->panel_settings = g_settings_new_with_path ("org.ukui.panel.toplevel", "/org/ukui/panel/toplevels/bottom/");
 
 	icon->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 	g_signal_connect (icon->priv->settings, "changed",
@@ -902,7 +1033,7 @@ gpm_tray_icon_finalize (GObject *object)
 	tray_icon = GPM_TRAY_ICON (object);
 
         //kobe
-        g_object_unref (tray_icon->priv->panel_settings);
+        //g_object_unref (tray_icon->priv->panel_settings);
 
 	g_object_unref (tray_icon->priv->status_icon);
 	g_object_unref (tray_icon->priv->engine);
