@@ -22,33 +22,56 @@
 #include <QStyleOption>
 #include <QPainter>
 #include <QMouseEvent>
+#include <QDir>
+#include "mainwindow.h"
 
 DeviceForm::DeviceForm(QWidget *parent) :
     QWidget(parent),
     ui(new Ui::DeviceForm)
 {
     ui->setupUi(this);
-//    mov = new QMovie(":/charging.gif");
     setAttribute(Qt::WA_StyledBackground,true);
+    setWindowFlags(Qt::FramelessWindowHint);
     ed = EngineDevice::getInstance();
-    set_timer();
+
+    ui->remaindata->setFixedHeight(11);
+    QFont font = ui->remaindata->font();
+    font.setPixelSize(11);
+    ui->remaindata->setFont(font);
+//    QPalette pal = this->palette();
+//    QColor color = this->palette().color(QPalette::Text);
+//    color.setAlphaF(0.5);
+//    pal.setColor(QPalette::Text,color);
+//    ui->remaindata->setPalette(pal);
+
 }
 
 DeviceForm::~DeviceForm()
 {
+    if(charge_animation)
+    {
+       charge_animation->deleteLater();
+       charge_animation = NULL;
+    }
     delete ui;
 }
 
-void DeviceForm::set_timer()
+void DeviceForm::set_timer(UpDeviceKind kind)
 {
     charge_animation = new QTimer(this);
-    connect(charge_animation,&QTimer::timeout,this,&DeviceForm::begin_charge_animation);
 
+    statics_icon_pre = ed->engine_kind_to_string(kind);
     for(int i = 0; i<=24; i++)
     {
-        QString filename = QString(":/charging/%1.png").arg(i);
-        animation_list.append(QPixmap(filename));
+        QString filename = QString(":/charging/%1/%2.png").arg(statics_icon_pre).arg(i);
+        QPixmap apix = QPixmap(filename);
+        if(!apix.isNull())
+        {
+            animation_list.append(apix);
+        }
     }
+    connect(charge_animation,&QTimer::timeout,this,&DeviceForm::begin_charge_animation);
+
 }
 
 void DeviceForm::set_charge_animation(bool flag)
@@ -72,21 +95,30 @@ void DeviceForm::set_charge_animation(bool flag)
 
 void DeviceForm::setIcon(QString name)
 {
-    if(name.contains("charging"))
+    if(animation_list.size()>1)
     {
-        set_charge_animation(true);
-        return;
+        if(name.contains("charging"))
+        {
+            set_charge_animation(true);
+            return;
+        }
     }
     set_charge_animation(false);
-//    QIcon icon = QIcon::fromTheme(name);
-    QIcon icon = QIcon(":/charging/0.png");
+
+    QString icon_str = QString(":/charging/%1/0.png").arg(statics_icon_pre);
+    QIcon icon = QIcon(icon_str);
+    if(icon.isNull())
+    {
+        icon = QIcon(":/charging/battery/0.png");
+    }
     QPixmap pixmap = icon.pixmap(QSize(32,32));
     ui->icon->setPixmap(pixmap);
 }
 
 void DeviceForm::begin_charge_animation()
 {
-    ui->icon->setPixmap(animation_list.at(charging_index));
+    if(charging_index < animation_list.size())
+        ui->icon->setPixmap(animation_list.at(charging_index));
     charging_index ++;
     if(charging_index > 24)
         charging_index = 0;
@@ -104,7 +136,15 @@ void DeviceForm::setKind(QString kind)
 
 void DeviceForm::setRemain(QString remain)
 {
-    ui->remaintext->setText(tr("RemainTime"));
+//    if(mDev.State == UP_DEVICE_STATE_DISCHARGING)
+//    {
+//        ui->remaintext->setText(tr("RemainTime"));
+//    }
+//    else
+//    {
+//        ui->remaintext->setText("");
+//    }
+    ui->remaintext->setText("");
     ui->remaindata->setText(remain);
 }
 
@@ -123,7 +163,6 @@ void DeviceForm::widget_property_change()
     setIcon(icon_name);
     setPercent(percentage);
     slider_changed(percent_number);
-
     setKind(kind);
     setRemain(predict);
 }
@@ -134,6 +173,11 @@ void DeviceForm::paintEvent(QPaintEvent *event)
     opt.init(this);
     QPainter p(this);
     style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
+    p.setBrush(opt.palette.color(QPalette::Base));
+    p.setPen(Qt::NoPen);
+    p.setOpacity(0.0);
+    p.setRenderHint(QPainter::Antialiasing);
+    p.drawRoundedRect(rect(),6,6);
     QWidget::paintEvent(event);
 }
 
@@ -191,8 +235,11 @@ void DeviceForm::set_device(DEVICE *dev)
 {
     if(dev == nullptr)
         return;
-    m_device = dev;
+//    m_device = dev;
     path = dev->m_dev.path;
+    /*prepare for device icon animation*/
+    UpDeviceKind kind = dev->m_dev.kind;
+    set_timer(kind);
     slot_device_change(dev);
     connect(ed,SIGNAL(signal_device_change(DEVICE*)),this,SLOT(slot_device_change(DEVICE*)));
 
@@ -205,24 +252,89 @@ void DeviceForm::slot_device_change(DEVICE* device)
     if(device->m_dev.path != path)
         return;
     icon_name = ed->engine_get_device_icon(device);
-//    qDebug()<<"slot_device_change------"<<icon_name;
     percentage = QString::number(device->m_dev.Percentage, 'f',0)+"%";
     percent_number = int (device->m_dev.Percentage);
     kind = ed->engine_kind_to_localised_text(device->m_dev.kind,0);
     predict = ed->engine_get_device_predict(device);
+//    qDebug () << "predict:" << predict;
+    mDev = device->m_dev;
+//    device_adjust_battery_parameters();
     widget_property_change();
 }
- void DeviceForm::slider_changed(int value)
- {
-     ui->progressBar->setValue(value);
-     ui->progressBar->setStyleSheet(QString(""
-         "	QProgressBar {"
-         "	border-radius: 2px;"
-         ""
-         "}"
-         "QProgressBar::chunk {"
-             "border-radius:2px;"
-             "	background-color: "
-             "%1;"
-         "}").arg(calculate_value(value,ui->progressBar->maximum())));
- }
+
+void DeviceForm::slider_changed(int value)
+{
+//    value = 17;
+    QPalette palette;
+    ui->progressBar->setValue(value);
+    if (value <= 10) {
+        palette= ui->progressBar->palette();
+        palette.setBrush(QPalette::Highlight, QBrush(QColor(240, 65, 52, 255)));
+        ui->progressBar->setPalette(palette);
+    } else if (value <= 20){
+        palette= ui->progressBar->palette();
+        palette.setBrush(QPalette::Highlight, QBrush(QColor(248,163,76,255)));
+        ui->progressBar->setPalette(palette);
+    }
+    else{
+        palette= ui->progressBar->palette();
+        palette.setBrush(QPalette::Highlight, QBrush(QColor(61,107,229,255)));
+        ui->progressBar->setPalette(palette);
+    }
+//    ui->progressBar->setStyleSheet(QString(""
+//     "	QProgressBar {"
+//     "	border-radius: 2px;"
+//     ""
+//     "}"
+//     "QProgressBar::chunk {"
+//         "border-radius:2px;"
+//         "	background-color: "
+//         "%1;"
+//     "}").arg(calculate_value(value,ui->progressBar->maximum())));
+}
+
+QString DeviceForm::device_get_ac_online()
+{
+    QDir power_dir("/sys/class/power_supply/");
+    if(!power_dir.exists())
+        return QString();
+
+    for(auto dir_name : power_dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot))
+    {
+        auto enter_name = power_dir.absoluteFilePath(dir_name);
+        QDir new_power_dir(enter_name);
+        for(auto file : new_power_dir.entryList(QDir::Files))
+        {
+            if(file == "online")
+            {
+                QFile absolute_file(new_power_dir.absoluteFilePath(file));
+                if(absolute_file.open(QIODevice::ReadOnly | QIODevice::Text))
+                {
+                    QByteArray ba = absolute_file.readAll();
+                    absolute_file.close();
+                    QString ac_online(ba);
+                    ac_online = ac_online.simplified();
+                    return ac_online;
+                }
+            }
+        }
+    }
+    return QString();
+}
+
+void DeviceForm::device_adjust_battery_parameters()
+{
+    if(mDev.kind != UP_DEVICE_KIND_BATTERY)
+        return;
+    //fix state is full ,but percentage is not reach 100;
+    if(mDev.State != UP_DEVICE_STATE_FULLY_CHARGED)
+        return;
+    QString online = device_get_ac_online();
+    if((online == "1") && (percent_number<100))
+    {
+        mDev.State = UP_DEVICE_STATE_CHARGING;
+        icon_name = ed->engine_get_dev_icon(mDev);
+        predict = ed->engine_get_dev_predict(mDev);
+    }
+
+}
