@@ -20,6 +20,7 @@
 #include <QDBusObjectPath>
 #include <QDBusMessage>
 #include <QDBusConnection>
+#include <QDBusInterface>
 #include <QDebug>
 
 #include "engine_common.h"
@@ -67,17 +68,12 @@ EngineDevice::EngineDevice(QObject *parent) : QObject(parent)
 
     power_device_get_devices();
     QDBusConnection::systemBus().connect(DBUS_SERVICE,DBUS_OBJECT,DBUS_SERVICE,
-                                         QString("device-added"),this,SLOT(power_device_add(QDBusMessage)));
+                                         ("DeviceAdded"),this,SLOT(power_device_add(QDBusObjectPath)));
     QDBusConnection::systemBus().connect(DBUS_SERVICE,DBUS_OBJECT,DBUS_SERVICE,
-                                         QString("device-removed"),this,SLOT(power_device_remove(QDBusMessage)));
+                                         ("DeviceRemoved"),this,SLOT(power_device_remove(QDBusObjectPath)));
     settings = new QGSettings(GPM_SETTINGS_SCHEMA);
     connect(settings,SIGNAL(changed(const QString&)),this,SLOT(engine_policy_settings_cb(const QString&)));
 
-//    QDBusConnection::systemBus().connect(MYDBUS_SERVICE,MYDBUS_OBJECT,MYDBUS_SERVICE,
-//                                         QString("deviceadded"),this,SLOT(mypower_device_add(QString)));
-//    QDBusConnection::systemBus().connect(MYDBUS_SERVICE,MYDBUS_OBJECT,MYDBUS_SERVICE,
-//                                         QString("deviceremoved"),this,SLOT(mypower_device_removed(QString)));
-
 }
 
 void EngineDevice::engine_policy_settings_cb(const QString& str)
@@ -102,50 +98,12 @@ void EngineDevice::engine_policy_settings_cb(const QString& str)
     power_device_recalculate_icon();
 }
 
-void EngineDevice::mypower_device_add(QString msg)
+void EngineDevice::power_device_add(QDBusObjectPath msg)
 {
-    DEVICE *dev = new DEVICE;
-    dev->m_dev.path = msg;
-    dev->m_dev.kind = UP_DEVICE_KIND_BATTERY;
-    dev->m_dev.warnlevel = (UpDeviceLevel)1;
-    dev->m_dev.Capacity = 88;
-    dev->m_dev.State = (UpDeviceState)1;
-
-    /*add to array*/
-    devices.append(dev);
-    /*connect notify signals*/
-    connect(dev,SIGNAL(device_property_changed(QDBusMessage,QString)),this,SLOT(power_device_change_callback(QDBusMessage,QString)));
-    /*recaculate state*/
-    Q_EMIT one_device_add(dev);
-}
-
-void EngineDevice::mypower_device_removed(QString msg)
-{
-    Q_FOREACH (auto item, devices)
-    {
-        if(item->m_dev.path == msg)
-        {
-            devices.removeOne(item);
-            Q_EMIT one_device_remove(item);
-            break;
-        }
-    }
-}
-
-void EngineDevice::power_device_add(QDBusMessage msg)
-{
-
     /* assign warning */
     /* check capacity */
     /* get device properties */
-    /* add old state for transitions */
-
-    /*connect notify signals*/
-    QDBusObjectPath objectPath;
-    const QDBusArgument &arg = msg.arguments().at(0).value<QDBusArgument>();
-    arg >> objectPath;
-
-    QDBusMessage msgTmp = QDBusMessage::createMethodCall(DBUS_SERVICE,objectPath.path(),
+    QDBusMessage msgTmp = QDBusMessage::createMethodCall(DBUS_SERVICE,msg.path(),
             "org.freedesktop.DBus.Properties","GetAll");
     msgTmp << DBUS_INTERFACE_DEV;
     QDBusMessage res = QDBusConnection::systemBus().call(msgTmp);
@@ -156,15 +114,32 @@ void EngineDevice::power_device_add(QDBusMessage msg)
         dbusArg >> map;
         UpDeviceKind kind = (UpDeviceKind)map.value("Type").toInt();
 
-        if(kind != UP_DEVICE_KIND_LINE_POWER && kind != UP_DEVICE_KIND_BATTERY && kind != UP_DEVICE_KIND_COMPUTER)
+        if(kind != UP_DEVICE_KIND_LINE_POWER && kind != UP_DEVICE_KIND_BATTERY && kind != UP_DEVICE_KIND_PHONE && kind != UP_DEVICE_KIND_COMPUTER)
             return;
 
         DEVICE *dev = new DEVICE;
-        dev->m_dev.path = objectPath.path();
+        dev->m_dev.path = msg.path();
         dev->m_dev.kind = kind;
         dev->m_dev.warnlevel = (UpDeviceLevel)map.value("WarningLevel").toUInt();
-        dev->m_dev.Capacity = map.value(QString("Capacity")).toDouble();
-        dev->m_dev.State = (UpDeviceState)map.value("State").toUInt();
+
+        dev->m_dev.Type = engine_kind_to_localised_text ((UpDeviceKind)map.value(QString("Type")).toInt(),1);
+        dev->m_dev.Model = map.value(QString("Model")).toString();
+        dev->m_dev.Device = map.value(QString("NativePath")).toString();
+        dev->m_dev.Capacity = (map.value(QString("Capacity")).toDouble());
+        dev->m_dev.Energy = QString::number(map.value(QString("Energy")).toDouble(), 'f', 1)+ " Wh";
+        dev->m_dev.EnergyEmpty= QString::number(map.value(QString("EnergyEmpty")).toDouble(), 'f', 1)+ " Wh";
+        dev->m_dev.EnergyFull = QString::number(map.value(QString("EnergyFull")).toDouble(), 'f', 1)+ " Wh";
+        dev->m_dev.EnergyRate = QString::number(map.value(QString("EnergyRate")).toDouble(), 'f', 1) + " W";
+
+        dev->m_dev.IsPresent = (map.value(QString("IsPresent")).toBool());
+
+        dev->m_dev.PowerSupply = boolToString(map.value(QString("PowerSupply")).toBool());
+        dev->m_dev.Percentage = map.value(QString("Percentage")).toDouble();
+        dev->m_dev.Percentage = ( (float)( (int)( (dev->m_dev.Percentage + 0.05) * 10 ) ) ) / 10;
+        dev->m_dev.Online = boolToString(map.value(QString("Online")).toBool());
+        dev->m_dev.State = (UpDeviceState)map.value(QString("State")).toInt();
+        dev->m_dev.TimeToEmpty = map.value(QString("TimeToEmpty")).toLongLong();
+        dev->m_dev.TimeToFull = map.value(QString("TimeToFull")).toLongLong();
 
         /*add to array*/
         devices.append(dev);
@@ -178,21 +153,16 @@ void EngineDevice::power_device_add(QDBusMessage msg)
     }
 }
 
-void EngineDevice::power_device_remove(QDBusMessage msg)
+void EngineDevice::power_device_remove(QDBusObjectPath msg)
 {
     Q_FOREACH (auto item, devices)
     {
         if(item->m_dev.path == msg.path())
-        //list.removed
         {
             devices.removeOne(item);
             Q_EMIT one_device_remove(item);
-//            delete item;
-//            item = NULL;
             break;
         }
-
-
     }
 
 }
@@ -266,16 +236,19 @@ void EngineDevice::putAttributes(QMap<QString,QVariant>& map,DEV &btrDetailData)
     if(map.contains("State"))
     {
         btrDetailData.State = (UpDeviceState)map.value(QString("State")).toInt();
+        //qDebug()<< "state:" << btrDetailData.State;
     }
     if(map.contains("Percentage"))
     {
         btrDetailData.Percentage = map.value(QString("Percentage")).toDouble();
         btrDetailData.Percentage = ( (float)( (int)( (btrDetailData.Percentage + 0.05) * 10 ) ) ) / 10;
-
     }
 
     if(map.contains("PowerSupply"))
         btrDetailData.PowerSupply = (map.value(QString("PowerSupply")).toBool()) ? tr("Yes") :tr("No");
+
+    if(map.contains("IsPresent"))
+        btrDetailData.IsPresent = (map.value(QString("IsPresent")).toBool());
 }
 
 void EngineDevice::power_device_change_callback(QDBusMessage msg,QString path)
@@ -301,7 +274,6 @@ void EngineDevice::power_device_change_callback(QDBusMessage msg,QString path)
     arg >> map;
     putAttributes(map,item->m_dev);
     Q_EMIT signal_device_change(item);
-//    getProperty(path,tmp_dev);
     if(item->m_dev.State != tmp_dev.State)
     {
         if(item->m_dev.State==UP_DEVICE_STATE_DISCHARGING)
@@ -331,12 +303,7 @@ void EngineDevice::power_device_change_callback(QDBusMessage msg,QString path)
         }
         //save new warning;
     }
-//    static int con = -1;
-//    if(con == -1)
-//    {
-//        Q_EMIT engine_signal_charge_low(tmp_dev);
-//        con = 1;
-//    }
+
     /*recaculate state*/
     power_device_recalculate_state();
 }
@@ -355,7 +322,6 @@ bool EngineDevice::power_device_recalculate_icon()
     /*call a function to obtain icon*/
     QString icon;
     icon = power_device_get_icon();
-//    qDebug() << "power_device_recalculate_icon-----"<<icon;
     if(icon.isNull())
     {
         if(previous_icon.isNull())
@@ -486,7 +452,7 @@ QString EngineDevice::power_device_get_icon()
         return icon;
     }
     /* we fallback to the ac_adapter icon */
-    return QString("gpm-ac-adapter");
+    return QString("battery-full-symbolic");
 }
 /**
  * power_device_get_icon_exact:
@@ -546,14 +512,11 @@ bool EngineDevice::engine_recalculate_summary ()
         Q_EMIT engine_signal_summary_change(summary);
         return true;
     }
-//    printf ("no change");
     return false;
 }
 
 /**
  * engine_get_summary:
- * @engine: This engine class instance
- * @string: The returned string
  *
  * Returns the complete tooltip ready for display
  **/
@@ -564,11 +527,13 @@ QString EngineDevice::engine_get_summary ()
     QString tooltip;
     QString part;
     bool is_present;
+    UpDeviceKind kind;
 
     Q_FOREACH (device, devices) {
         is_present = device->m_dev.IsPresent;
         state = device->m_dev.State;
-        if (!is_present)
+        kind = device->m_dev.kind;
+        if ((!is_present)||(kind != UP_DEVICE_KIND_BATTERY))
             continue;
         if (state == UP_DEVICE_STATE_EMPTY)
             continue;
@@ -666,7 +631,9 @@ QString EngineDevice::engine_get_device_predict(DEVICE* dv)
     time_to_empty = dv->m_dev.TimeToEmpty;
     time_to_full = dv->m_dev.TimeToFull;
     if (!is_present)
+    {
         return NULL;
+    }
 
     kind_desc = engine_kind_to_localised_text (kind, 1);
 
@@ -686,6 +653,7 @@ QString EngineDevice::engine_get_device_predict(DEVICE* dv)
             result = tr("fully charged");
         else
             result = tr("charging");
+        result = tr("fully charged");
 
 //        if (kind == UP_DEVICE_KIND_BATTERY && time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
 //            time_to_empty_str = engine_get_timestring (time_to_empty_round);
@@ -697,15 +665,15 @@ QString EngineDevice::engine_get_device_predict(DEVICE* dv)
 
     } else if (state == UP_DEVICE_STATE_DISCHARGING) {
 
-        if (time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
-            time_to_empty_str = engine_get_timestring (time_to_empty_round);
-            result = time_to_empty_str;
+//        if (time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
+//            time_to_empty_str = engine_get_timestring (time_to_empty_round);
+//            result = time_to_empty_str;
 
-        } else {
-            result = tr("discharging(%1%)").arg(percentage);
-
-        }
+//        } else {
+//            result = tr("discharging(%1%)").arg(percentage);
 
+//        }
+        result = tr("not charging");
     } else if (state == UP_DEVICE_STATE_CHARGING) {
         result = tr("charging");
 //        if (time_to_full_round > GPM_UP_TEXT_MIN_TIME &&
@@ -738,6 +706,7 @@ QString EngineDevice::engine_get_device_predict(DEVICE* dv)
         result = QString("%1(%2%)").arg(kind_desc).arg(percentage);
     }
     return result;
+    qDebug ()<< "result:" << result;
 }
 
 /**
@@ -771,87 +740,28 @@ QString EngineDevice::engine_get_device_summary(DEVICE* dv)
 
     kind_desc = engine_kind_to_localised_text (kind, 1);
 
-    if (kind == UP_DEVICE_KIND_MOUSE ||
-        kind == UP_DEVICE_KIND_KEYBOARD ||
-        kind == UP_DEVICE_KIND_PDA)
-    {
-        result = QString("%1 (%2%)").arg(kind_desc).arg(percentage);
-        return result;
-    }
-
-    /* we care if we are on AC */
-    if (kind == UP_DEVICE_KIND_PHONE) {
-        if (state == UP_DEVICE_STATE_CHARGING || state != UP_DEVICE_STATE_DISCHARGING) {
-
-            result = QString("%1 charging (%2%)").arg(kind_desc).arg(percentage);
-            return result;
-        }
-        result = QString("%1 (%2%)").arg(kind_desc).arg(percentage);
-
-        return result;
-    }
-
-    time_to_full_round = precision_round_down (time_to_full, GPM_UP_TIME_PRECISION);
-    time_to_empty_round = precision_round_down (time_to_empty, GPM_UP_TIME_PRECISION);
-
     if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
 
-        if (kind == UP_DEVICE_KIND_BATTERY && time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
-            time_to_empty_str = engine_get_timestring (time_to_empty_round);
-            result = QString("Battery is fully charged.\nProvides %1 laptop runtime").arg(time_to_empty_str);
-        } else {
-            result = QString("%1 is fully charged").arg(kind_desc);
-        }
+        result = tr("%1% available, charged").arg(percentage);
 
     } else if (state == UP_DEVICE_STATE_DISCHARGING) {
 
-        if (time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
-            time_to_empty_str = engine_get_timestring (time_to_empty_round);
-            result = QString("%1 %2 remaining (%3%)").arg(kind_desc).arg(time_to_empty_str).arg(percentage);
-
-        } else {
-            result = QString("%1 discharging (%2%)").arg(kind_desc).arg(percentage);
-
-        }
+        result = tr("%1% available, not charging").arg(percentage);
 
     } else if (state == UP_DEVICE_STATE_CHARGING) {
 
-        if (time_to_full_round > GPM_UP_TEXT_MIN_TIME &&
-            time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
-
-            /* display both discharge and charge time */
-            time_to_full_str = engine_get_timestring (time_to_full_round);
-            time_to_empty_str = engine_get_timestring (time_to_empty_round);
-
-            /* TRANSLATORS: the device is charging, and we have a time to full and empty */
-            result = QString("%1 %2 until charged (%3%)\nProvides %4 battery runtime")
-                    .arg(kind_desc).arg(time_to_full_str).arg(percentage).arg(time_to_empty_str);
-
-        } else if (time_to_full_round > GPM_UP_TEXT_MIN_TIME) {
-
-            /* display only charge time */
-            time_to_full_str = engine_get_timestring (time_to_full_round);
-
-            /* TRANSLATORS: device is charging, and we have a time to full and a percentage */
-            result = QString("%1 %2 until charged (%3%)").arg(kind_desc).arg(time_to_full_str).arg(percentage);
-
-        } else {
-
-            /* TRANSLATORS: device is charging, but we only have a percentage */
-            result = QString("%1 charging (%2%)").arg(kind_desc).arg(percentage);
-
-        }
+        result = tr("%1% available, charging").arg(percentage);
 
     } else if (state == UP_DEVICE_STATE_PENDING_DISCHARGE) {
 
         /* TRANSLATORS: this is only shown for laptops with multiple batteries */
-        result = QString("%1 waiting to discharge (%2%)").arg(kind_desc).arg(percentage);
+        result = tr("%1 waiting to discharge (%2%)").arg(kind_desc).arg(percentage);
 
 
     } else if (state == UP_DEVICE_STATE_PENDING_CHARGE) {
 
         /* TRANSLATORS: this is only shown for laptops with multiple batteries */
-        result = QString("%1 waiting to charge (%2%)").arg(kind_desc).arg(percentage);
+        result = tr("%1 waiting to charge (%2%)").arg(kind_desc).arg(percentage);
 
     } else {
         printf ("in an undefined state we are not charging or "
@@ -943,7 +853,7 @@ QString EngineDevice::engine_kind_to_localised_text (UpDeviceKind kind, uint num
         break;
     case UP_DEVICE_KIND_PHONE:
         /* TRANSLATORS: cell phone (mobile...) */
-        text =  ("Cell phone");
+        text =  tr("Cell phone");
         break;
     case UP_DEVICE_KIND_MEDIA_PLAYER:
         /* TRANSLATORS: media player, mp3 etc */
@@ -968,15 +878,23 @@ QString EngineDevice::engine_kind_to_localised_text (UpDeviceKind kind, uint num
 QString EngineDevice::engine_get_device_icon_index (qreal percentage)
 {
     if (percentage < 10)
-        return "000";
+        return "10";
+    else if (percentage < 20)
+        return "20";
     else if (percentage < 30)
-        return "020";
+        return "30";
+    else if (percentage < 40)
+        return "40";
     else if (percentage < 50)
-        return "040";
+        return "50";
+    else if (percentage < 60)
+        return "60";
     else if (percentage < 70)
-        return "060";
+        return "70";
+    else if (percentage < 80)
+        return "80";
     else if (percentage < 90)
-        return "080";
+        return "90";
     return "100";
 }
 
@@ -1009,7 +927,6 @@ QString EngineDevice::engine_get_device_icon (DEVICE *device)
     } else if (kind == UP_DEVICE_KIND_UPS) {
         if (!is_present) {
             /* battery missing */
-//            result.sprintf ("gpm-%s-missing", prefix);
             result.sprintf ("gpm-%s-missing", prefix.toStdString().c_str());
 
         } else if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
@@ -1025,33 +942,36 @@ QString EngineDevice::engine_get_device_icon (DEVICE *device)
         }
     } else if (kind == UP_DEVICE_KIND_BATTERY) {
         if (!is_present) {
-            /* battery missing */
-            result = QString ("gpm-%1-missing").arg(prefix);
+            /* battery missing: battery-missing-symbolic*/
+            result = QString ("%1-missing-symbolic").arg(prefix);
 
         } else if (state == UP_DEVICE_STATE_EMPTY) {
-            result = QString ("gpm-%1-empty").arg(prefix);
+            /* battery-empty-symbolic */
+            result = QString ("%1-empty-symbolic").arg(prefix);
 
         } else if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
-                    result = QString ("gpm-%1-charged").arg(prefix);
+            /* battery-full-charged-symbolic */
+            result = QString ("%1-full-charged-symbolic").arg(prefix);
         } else if (state == UP_DEVICE_STATE_CHARGING) {
             index_str = engine_get_device_icon_index (percentage);
-            result = QString("gpm-%1-%2-charging").arg(prefix).arg(index_str);
+            /* battery-level-percent-charging-symbolic */
+            result = QString("%1-level-%2-charging-symbolic").arg(prefix).arg(index_str);
 
         } else if (state == UP_DEVICE_STATE_DISCHARGING) {
             index_str = engine_get_device_icon_index (percentage);
-            result = QString("gpm-%1-%2").arg(prefix).arg(index_str);
+            result = QString("%1-level-%2-symbolic").arg(prefix).arg(index_str);
 
         } else if (state == UP_DEVICE_STATE_PENDING_CHARGE) {
             index_str = engine_get_device_icon_index (percentage);
             /* FIXME: do new grey icons */
-            result = QString("gpm-%1-%2-charging").arg(prefix).arg(index_str);
+            result = QString("%1-level-%2-charging-symbolic").arg(prefix).arg(index_str);
 
         } else if (state == UP_DEVICE_STATE_PENDING_DISCHARGE) {
             index_str = engine_get_device_icon_index (percentage);
-            result = QString("gpm-%1-%2").arg(prefix).arg(index_str);
+            result = QString("%1-level-%2-symbolic").arg(prefix).arg(index_str);
 
         } else {
-            result =  ("gpm-battery-missing");
+            result =  ("battery-missing-symbolic");
         }
 
     } else if (kind == UP_DEVICE_KIND_MOUSE ||
@@ -1067,17 +987,121 @@ QString EngineDevice::engine_get_device_icon (DEVICE *device)
         } else if (state == UP_DEVICE_STATE_DISCHARGING) {
             index_str = engine_get_device_icon_index (percentage);
             result = QString("gpm-%1-%2").arg(prefix).arg(index_str);
+        } else if (state == UP_DEVICE_STATE_CHARGING) {
+            index_str = engine_get_device_icon_index (percentage);
+            result = QString("gpm-%1-%2-charging").arg(prefix).arg(index_str);
         }
     }
 
     /* nothing matched */
     if (result.isNull()) {
-//        printf ("nothing matched, falling back to default icon");
         result =  ("dialog-warning");
     }
     return result;
 }
 
+QString EngineDevice::engine_get_dev_icon (DEV dev)
+{
+    QString prefix;
+    QString index_str;
+    UpDeviceKind kind;
+    UpDeviceState state;
+    bool is_present;
+    QString result;
+    qreal percentage;
+
+    kind = dev.kind;
+    state = dev.State;
+    percentage = dev.Percentage;
+    is_present = dev.IsPresent;
+    /* get correct icon prefix */
+    prefix = engine_kind_to_string (kind);
+
+        if (kind == UP_DEVICE_KIND_BATTERY) {
+            if (!is_present) {
+                /* battery missing: battery-missing-symbolic*/
+                result = QString ("%1-missing-symbolic").arg(prefix);
+
+            } else if (state == UP_DEVICE_STATE_EMPTY) {
+                /* battery-empty-symbolic */
+                result = QString ("%1-empty-symbolic").arg(prefix);
+
+            } else if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
+                /* battery-full-charged-symbolic */
+                result = QString ("%1-full-charged-symbolic").arg(prefix);
+            } else if (state == UP_DEVICE_STATE_CHARGING) {
+                index_str = engine_get_device_icon_index (percentage);
+                /* battery-level-percent-charging-symbolic */
+                result = QString("%1-level-%2-charging-symbolic").arg(prefix).arg(index_str);
+
+            } else if (state == UP_DEVICE_STATE_DISCHARGING) {
+                index_str = engine_get_device_icon_index (percentage);
+                result = QString("%1-level-%2-symbolic").arg(prefix).arg(index_str);
+
+            } else if (state == UP_DEVICE_STATE_PENDING_CHARGE) {
+                index_str = engine_get_device_icon_index (percentage);
+                /* FIXME: do new grey icons */
+                result = QString("%1-level-%2-charging-symbolic").arg(prefix).arg(index_str);
+
+            } else if (state == UP_DEVICE_STATE_PENDING_DISCHARGE) {
+                index_str = engine_get_device_icon_index (percentage);
+                result = QString("%1-level-%2-symbolic").arg(prefix).arg(index_str);
+
+            } else {
+                result =  ("battery-missing-symbolic");
+            }
+
+        }
+    if (result.isNull()) {
+        result =  ("dialog-warning");
+    }
+    return result;
+}
+
+QString EngineDevice::engine_get_dev_predict(DEV dev)
+{
+    QString result;
+    QString kind_desc;
+    uint time_to_empty_round;
+    QString time_to_empty_str;
+    UpDeviceKind kind;
+    UpDeviceState state;
+    double percentage;
+    bool is_present;
+    uint time_to_full;
+    uint time_to_empty;
+
+    kind = dev.kind;
+    is_present = dev.IsPresent;
+    state = dev.State;
+    percentage = dev.Percentage;
+
+    time_to_empty = dev.TimeToEmpty;
+    time_to_full = dev.TimeToFull;
+    if (!is_present)
+        return NULL;
+
+    kind_desc = engine_kind_to_localised_text (kind, 1);
+
+    time_to_empty_round = precision_round_down (time_to_empty, GPM_UP_TIME_PRECISION);
+
+    if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
+        result = tr("fully charged");
+    } else if (state == UP_DEVICE_STATE_DISCHARGING) {
+        if (time_to_empty_round > GPM_UP_TEXT_MIN_TIME) {
+            time_to_empty_str = engine_get_timestring (time_to_empty_round);
+            result = time_to_empty_str;
+        } else {
+            result = tr("discharging(%1%)").arg(percentage);
+        }
+    } else if (state == UP_DEVICE_STATE_CHARGING) {
+        result = tr("charging");
+    }  else {
+        result = QString("%1(%2%)").arg(kind_desc).arg(percentage);
+    }
+    return result;
+}
+
 QString EngineDevice::engine_get_state_text (UpDeviceState state)
 {
     QString state_text;
