@@ -21,10 +21,35 @@
 #include <QSharedMemory>
 #include <QDebug>
 #include <QTranslator>
+#include <KWindowEffects>
+#include <QDesktopWidget>
+#include <X11/Xlib.h>
+#include <QFileInfo>
 
 int main(int argc, char *argv[])
 {
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+//    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+    Display *display = XOpenDisplay(NULL);
+    if (NULL == display) {
+	qDebug() << "Can't open display!";
+	return -1;
+    }
+    Screen *screen = DefaultScreenOfDisplay(display);
+    if (NULL == screen) {
+	qDebug() << "Get default screen failed!";
+        return -1;
+    }
+    int width = screen->width;
+
+    if (width > 2560) {
+        #if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
+                QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+                QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+        #endif
+    }
+
+    XCloseDisplay(display);
+
     QApplication a(argc, argv);
     QSharedMemory mem("SingleApp-ukui-power-manager-tray");
     if(mem.attach())
@@ -48,18 +73,27 @@ int main(int argc, char *argv[])
         exit(0);
     }
 
-    QString locale = QLocale::system().name();
+//    QString locale = QLocale::system().name();
+//    QTranslator translator;
+//    QString qmfile = QString("/usr/share/ukui-power-manager/tray/translations/%1.qm").arg(locale);
+//    QFileInfo fl(qmfile);
+//    if (fl.exists()) {
+//        translator.load(qmfile);
+//        a.installTranslator(&translator);
+//    }
     QTranslator translator;
-    QString qmfile = QString(":/%1.qm").arg(locale);
-    translator.load(qmfile);
-    a.installTranslator(&translator);
+    if (translator.load(QLocale(),"ukui-power-manager-tray","_",QM_FILES_INSTALL_PATH))
+        a.installTranslator(&translator);
+    else
+        qDebug()<<"load ukui-power-manager-tray qm file error";
+
     QFile file(":/main.qss");
     file.open(QFile::ReadOnly);
     qApp->setStyleSheet(file.readAll());
     file.close();
-//    QIcon::setThemeName("ukui-icon-theme-default");
-    QIcon::setThemeName("ukui-icon-theme");
+//    QIcon::setThemeName("ukui-icon-theme");
     MainWindow w;
+    KWindowEffects::enableBlurBehind(w.winId(),true);
     w.hide();
 
     return a.exec();
