@@ -30,13 +30,20 @@
 #include <QFile>
 #include <customstyle.h>
 #include <QDBusReply>
+#include <QPainterPath>
 
-#define POWER_SCHEMA "org.ukui.power-manager"
-#define POWER_SCHEMA_KEY "power-manager"
-#define PANEL_DBUS_SERVICE "com.ukui.panel.desktop"
-#define PANEL_DBUS_PATH "/"
-#define PANEL_DBUS_INTERFACE "com.ukui.panel.desktop"
+#define POWER_SCHEMA                "org.ukui.power-manager"
+#define UKUI_STYLE                  "org.ukui.style"
+#define UKUI_STYLE_STYLE_NAME       "style-name"
+#define POWER_SCHEMA_KEY            "power-manager"
+#define PANEL_DBUS_SERVICE          "com.ukui.panel.desktop"
+#define PANEL_DBUS_PATH             "/"
+#define PANEL_DBUS_INTERFACE        "com.ukui.panel.desktop"
+#define PANEL_SETTINGS              "org.ukui.panel.settings"
+#define PANEL_SETTINGS_KEY_HEIGHT   "panelsize"
+#define PANEL_SETTINGS_KEY_POSITION "panelposition"
 
+double MainWindow::transparent = 0.7;
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
@@ -44,31 +51,26 @@ MainWindow::MainWindow(QWidget *parent) :
     ed = EngineDevice::getInstance();
     ui->setupUi(this);
     initData();
-//    setting = new QGSettings(POWER_SCHEMA);
-//    connect(setting,SIGNAL(changed(const QString &)),this,SLOT(iconThemeChanged()));
 
     trayIcon = new QSystemTrayIcon(this);
     connect(trayIcon,SIGNAL(activated(QSystemTrayIcon::ActivationReason)),this,SLOT(onActivatedIcon(QSystemTrayIcon::ActivationReason)));
     connect(ed,SIGNAL(icon_changed(QString)),this,SLOT(onIconChanged(QString)));
     connect(ed,SIGNAL(engine_signal_summary_change(QString)),this,SLOT(onSumChanged(QString)));
-//    connect(ed,SIGNAL(engine_signal_charge_low(DEV)),this,SLOT(low_battery_notify(DEV)));
-//    connect(ed,SIGNAL(engine_signal_charge_critical(DEV)),this,SLOT(critical_battery_notify(DEV)));
-//    connect(ed,SIGNAL(engine_signal_charge_action(DEV)),this,SLOT(action_battery_notify(DEV)));
-//    connect(ed,SIGNAL(engine_signal_discharge(DEV)),this,SLOT(discharge_notify(DEV)));
-//    connect(ed,SIGNAL(engine_signal_fullycharge(DEV)),this,SLOT(full_charge_notify(DEV)));
 
     connect(ed,SIGNAL(one_device_add(DEVICE*)),this,SLOT(add_one_device(DEVICE *)));
     connect(ed,SIGNAL(one_device_remove(DEVICE*)),this,SLOT(remove_one_device(DEVICE*)));
 
+    get_window_style();
     initUi();
     ed->engine_policy_settings_cb("iconPolicy");
-
+    ed->engine_recalculate_summary();
+//    installEventFilter(this);
 }
 
 void MainWindow::onSumChanged(QString str)
 {
     Q_UNUSED(str);
-//    trayIcon->setToolTip(str);
+    trayIcon->setToolTip(str);
 }
 
 void MainWindow::discharge_notify(DEV dev)
@@ -169,22 +171,6 @@ void MainWindow::action_battery_notify(DEV dev)
 
 void MainWindow::onIconChanged(QString str)
 {
-    /*if(!str.isNull())
-    {
-        QIcon icon = QIcon::fromTheme(str);
-        trayIcon->setIcon(icon);
-        trayIcon->show();
-
-        str = ":/status/"+str+".png";
-        QPixmap a(str);
-        a = a.scaled(32,80);
-        QIcon icon(a);
-        trayIcon->setIcon(icon);
-        trayIcon->show();
-    }
-    else {
-        trayIcon->hide();
-    }*/
 
     want_percent = false;
     if(!str.isNull())
@@ -212,7 +198,6 @@ QPixmap MainWindow::set_percent_pixmap(QString text)
 {
     QFont m_font("Arial");
     QFontMetrics fmt(m_font);
-//    QPixmap result(fmt.width(text), fmt.height());
     QPixmap result(fmt.width(text), 32);
 
     QRect rect(0,0,fmt.width(text), 32);
@@ -220,7 +205,6 @@ QPixmap MainWindow::set_percent_pixmap(QString text)
     QPainter painter(&result);
     painter.setFont(m_font);
     painter.setPen(QColor(255,255,255));
-    //painter.drawText(const QRectF(fmt.width(text), fmt.height()),Qt::AlignLeft, text);
     painter.drawText(rect,Qt::AlignVCenter|Qt::AlignLeft,text);
 
     return result;
@@ -254,10 +238,6 @@ QIcon MainWindow::get_percent_icon(QIcon icon)
 
   painter_h.end();
 
-//  QFile file("percent.png");
-//  file.open(QIODevice::WriteOnly);
-//  result_image_h.save(&file,"PNG");
-//  file.close();
   QIcon result_icon = QIcon(result_image_h);
   return result_icon;
 }
@@ -280,11 +260,11 @@ void MainWindow::show_percentage_func()
     want_percent = !want_percent;
     if(want_percent)
     {
-        percent_label->setPixmap(QPixmap(":/apps/tick.png"));
+//        percent_label->setPixmap(QPixmap(":/apps/tick.png"));
         onIconChanged(ed->previous_icon);
     }
     else {
-        percent_label->setPixmap(QPixmap());
+//        percent_label->setPixmap(QPixmap());
         onIconChanged(ed->previous_icon);
     }
 
@@ -304,76 +284,67 @@ void MainWindow::set_window_position( )
     totalHeight = screenGeometry.height();
     totalWidth = screenGeometry.width();
 
+    int distance = 8;
     int number = QGuiApplication::screens().size();
-//    qDebug()<<"trayIcon:"<<trayIcon->geometry();
     if (number > 1)
     {
-//        QDesktopWidget* desktopWidget = QApplication::desktop();
         QRect main_rect = QGuiApplication::screens().at(0)->geometry();//获取设备屏幕大小
         QRect copy_rect = QGuiApplication::screens().at(1)->geometry();//获取设备屏幕大小
-        int n = getTaskbarPos("position");
-        int m = getTaskbarHeight("height");
+        int n = 0;
+        int m = 46;
+
+        n = getTaskbarPos("position");
+        m = getTaskbarHeight("height");
         if(n == 0){
             //任务栏在下侧
-            availableWidth = main_rect.width();
-            availableHeight = main_rect.height()-m;
-            this->setGeometry(availableWidth-this->width()-3,availableHeight-this->height()-3,this->width(),this->height());
-//            if (availableWidth - rect.x() - 3 < this->width())
-//                this->setGeometry(availableWidth-this->width()-3,availableHeight-this->height()-3,this->width(),this->height());
-//            else
-//                this->setGeometry(rect.x(),availableHeight-this->height()-3,this->width(),this->height());
+            availableWidth = screenGeometry.x()+screenGeometry.width();
+            availableHeight = screenGeometry.y()+screenGeometry.height();
+            setGeometry(availableWidth-this->width()-distance,availableHeight-this->height()-m-distance,this->width(),this->height());
+
         }else if(n == 1){
             //任务栏在上侧
-            this->setGeometry(availableWidth-this->width()-3,m+3,this->width(),this->height());
-//            if (availableWidth - rect.x() - 3 < this->width())
-//                this->setGeometry(availableWidth-this->width()-3,m+3,this->width(),this->height());
-//            else
-//                this->setGeometry(rect.x(),m+3,this->width(),this->height());
+            availableWidth = screenGeometry.x()+screenGeometry.width();
+            availableHeight = screenGeometry.y()+screenGeometry.height();
+            setGeometry(availableWidth-this->width()-distance,screenGeometry.y()+m+distance,this->width(),this->height());
+
         } else if (n == 2){
             //任务栏在左侧
-            availableWidth = main_rect.width()-m;
-            availableHeight = main_rect.height();
-            if (availableHeight - rect.y() -3 > this->height() )
-                this->setGeometry(m + 3,rect.y(),this->width(),this->height());
-            else
-                this->setGeometry(m+3,availableHeight - this->height() -3,this->width(),this->height());
+            availableWidth = screenGeometry.x()+screenGeometry.width();
+            availableHeight = screenGeometry.y()+screenGeometry.height();
+            setGeometry(screenGeometry.x()+m+distance,availableHeight-this->height()-distance,this->width(),this->height());
         } else if (n == 3){
             //任务栏在右侧
-            availableWidth = copy_rect.x() + copy_rect.width()-m;
-            availableHeight = copy_rect.height();
-            if (availableHeight - rect.y() -3 > this->height() )
-                this->setGeometry(availableWidth - this->width() - 3,rect.y(),this->width(),this->height());
-            else
-                this->setGeometry(availableWidth - this->width() - 3,availableHeight - this->height() -3,this->width(),this->height());
-
+            availableWidth = screenGeometry.x()+screenGeometry.width();
+            availableHeight = screenGeometry.y()+screenGeometry.height();
+            setGeometry(availableWidth-this->width()-m-distance,availableHeight-this->height()-distance,this->width(),this->height());
         }
     }
     else if(totalWidth == availableWidth )//down and up
     {
         if (rect.y() > availableHeight/2){
-            if (availableWidth - rect.x() - 3 < this->width())
-                this->setGeometry(availableWidth-this->width()-3,availableHeight-this->height()-3,this->width(),this->height());
+            if (availableWidth - rect.x() - distance < this->width())
+                this->setGeometry(availableWidth-this->width()-distance,availableHeight-this->height()-distance,this->width(),this->height());
             else
-                this->setGeometry(rect.x(),availableHeight-this->height()-3,this->width(),this->height());
+                this->setGeometry(rect.x(),availableHeight-this->height()-distance,this->width(),this->height());
         }else{
-            if (availableWidth - rect.x() - 3 < this->width())
-                this->setGeometry(availableWidth-this->width()-3,totalHeight-availableHeight+3,this->width(),this->height());
+            if (availableWidth - rect.x() - distance < this->width())
+                this->setGeometry(availableWidth-this->width()-distance,totalHeight-availableHeight+distance,this->width(),this->height());
             else
-                this->setGeometry(rect.x(),totalHeight-availableHeight+3,this->width(),this->height());
+                this->setGeometry(rect.x(),totalHeight-availableHeight+distance,this->width(),this->height());
         }
     }
     else if (totalHeight == availableHeight)//right and left
     {
         if (rect.x() > availableWidth/2){
-            if (availableHeight - rect.y() -3 > this->height() )
-                this->setGeometry(availableWidth - this->width() - 3,rect.y(),this->width(),this->height());
+            if (availableHeight - rect.y() -distance > this->height() )
+                this->setGeometry(availableWidth - this->width() - distance,rect.y(),this->width(),this->height());
             else
-                this->setGeometry(availableWidth - this->width() - 3,totalHeight - this->height() -3,this->width(),this->height());
+                this->setGeometry(availableWidth - this->width() - distance,totalHeight - this->height() -distance,this->width(),this->height());
         } else {
-            if (availableHeight - rect.y() -3 > this->height() )
-                this->setGeometry(totalWidth - availableWidth + 3,rect.y(),this->width(),this->height());
+            if (availableHeight - rect.y() -distance > this->height() )
+                this->setGeometry(totalWidth - availableWidth + distance,rect.y(),this->width(),this->height());
             else
-                this->setGeometry(totalWidth-availableWidth+3,totalHeight - this->height() -3,this->width(),this->height());
+                this->setGeometry(totalWidth-availableWidth+distance,totalHeight - this->height() -distance,this->width(),this->height());
         }
     }
 }
@@ -381,14 +352,33 @@ void MainWindow::set_window_position( )
 
 void MainWindow::onActivatedIcon(QSystemTrayIcon::ActivationReason reason)
 {
+    QString style_string;
     switch(reason) {
         case QSystemTrayIcon::Trigger: {
-                set_window_position();
                 if (!this->isHidden()) {
                     this->hide();
                 }
                 else
-                    this->show();
+                {
+                    transparent = get_window_opacity();
+//                    if(style_nm == "ukui-dark")
+//                    {
+//                        style_string = QString("#centralWidget {"
+//                                                       "background-color:rgba(19,19,20,%1);"
+//                                                       "border-radius:6px;}").arg(transparent);
+//                    }
+//                    else
+//                    {
+//                        style_string = QString("#centralWidget {"
+//                                                       "background-color:rgba(255,255,255,%1);"
+//                                                       "border-radius:6px;}").arg(transparent);
+
+//                    }
+//                    setStyleSheet(style_string);
+
+                    this->showNormal();
+                    set_window_position();
+                }
                 break;
         }
 
@@ -401,20 +391,22 @@ void MainWindow::onActivatedIcon(QSystemTrayIcon::ActivationReason reason)
 void MainWindow::initData()
 {
     want_percent = false;
-    pressQss = "QLabel{background-color:#3593b5;}";
-    releaseQss = "QLabel{background-color:#283138;}";
 }
 
 void MainWindow::initUi()
 {
     setWindowFlags(Qt::FramelessWindowHint|Qt::Popup);
-//    this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint | Qt::SplashScreen);
     setAttribute(Qt::WA_StyledBackground,true);
     setAttribute(Qt::WA_TranslucentBackground);
 
+    QPainterPath path;
+    QRect rect = this->rect();
+    rect.adjust(1,1,-1,-1);
+    path.addRoundedRect(rect,6,6);
+    setProperty("blurRegion",QRegion(path.toFillPolygon().toPolygon()));
+
     dev_number = get_engine_dev_number();
-//    dev_number = 3;
-    resize(360,72 + 8 + 82*(dev_number>3?3:dev_number));
+    resize(360,76 + 8 + 82*(dev_number>3?3:dev_number));
 
     ui->listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     ui->listWidget->setSpacing(0);
@@ -423,7 +415,7 @@ void MainWindow::initUi()
     ui->mainVerticalLayout->setSpacing(0);
     ui->horizontalLayout->setContentsMargins(0,0,4,0);
     ui->horizontalLayout->setSpacing(0);
-    ui->widget->setFixedHeight(26);
+    ui->widget->setFixedHeight(30);
     if(dev_number > 3)
     {
         ui->listWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
@@ -433,9 +425,9 @@ void MainWindow::initUi()
         ui->listWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     }
     ui->power_title->setText(tr("PowerManagement"));
-    ui->power_title->setAlignment(Qt::AlignLeft);
+    ui->power_title->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
-    connect(ui->statistic_button,SIGNAL(released()),this,SLOT(activate_power_statistic()));
+//    connect(ui->statistic_button,SIGNAL(released()),this,SLOT(activate_power_statistic()));
 
     ui->statistic_button->setText(tr("Stats"));//adapt to chinese
     ui->statistic_button->setFixedWidth(54);
@@ -445,90 +437,41 @@ void MainWindow::initUi()
                                         "QPushButton::hover {background-color:rgba(255,255,255,0);color:rgba(151,175,241,1);font-size:14px;}"
                                         "QPushButton::pressed {background-color:rgba(255,255,255,0);color:rgba(61,107,229,1);font-size:12px;}"
                                         );
-    setStyleSheet("#centralWidget {"
-                  "background-color:rgba(19,19,20,0.7);"
-                  "border-radius:6px;}"
-                  );
+    ui->statistic_button->setCheckable (false);
+    ui->statistic_button->setVisible (false);
+    transparent = get_window_opacity();
+//    QString style_string = QString("#centralWidget {"
+//                                   "background-color:rgba(19,19,20,%1);"
+//                                   "border-radius:6px;}").arg(transparent);
+//    setStyleSheet(style_string);
 
     get_power_list();
 
     menu = new QMenu(this);
     menu->setAttribute(Qt::WA_TranslucentBackground);
     menu->setWindowFlag(Qt::FramelessWindowHint);
-    set_preference  = new QWidgetAction(menu);
-    show_percentage = new QWidgetAction(menu);
-    set_bright = new QWidgetAction(menu);
-
-    QHBoxLayout *hbox_preference = new QHBoxLayout;
-    QLabel *preference_label = new QLabel(this);
-    QLabel *preference_text = new QLabel(this);
-    QWidget *preference_widget = new QWidget(this);
-    preference_label->setFixedSize(QSize(16,16));
-    preference_label->setPixmap(QPixmap(":/apps/setting.svg"));
-    preference_text->setText(tr("SetPower"));
-    preference_label->setStyleSheet("QLabel{background:transparent;border:0px;}");
-    preference_text->setStyleSheet("QLabel{background:transparent;border:0px;}");
-    hbox_preference->addWidget(preference_label);
-    hbox_preference->addWidget(preference_text);
-    preference_widget->setLayout(hbox_preference);
-    preference_widget->setFocusPolicy(Qt::NoFocus);
-    preference_widget->setFixedSize(QSize(244,36));
-    hbox_preference->setSpacing(10);
-    set_preference->setDefaultWidget(preference_widget);
-    preference_widget->setStyleSheet("QWidget{background:transparent;border:0px;border-radius:4px}\
-                                     QWidget:hover{background-color:rgba(255,255,255,0.15);}");
-
-    QHBoxLayout *hbox_percent = new QHBoxLayout;
-    percent_label = new QLabel(this);
-    QLabel *percent_text = new QLabel(this);
-    QWidget *percent_widget = new QWidget(this);
-    percent_label->setFixedSize(QSize(16,16));
-    percent_label->setPixmap(QPixmap(":/apps/tick.png"));
-    percent_text->setText(tr("ShowPercentage"));
-    percent_label->setStyleSheet("QLabel{background:transparent;border:0px;}");
-    percent_text->setStyleSheet("QLabel{background:transparent;border:0px;}");
-    hbox_percent->addWidget(percent_label);
-    hbox_percent->addWidget(percent_text);
-    percent_widget->setLayout(hbox_percent);
-    percent_widget->setFocusPolicy(Qt::NoFocus);
-    percent_widget->setFixedSize(QSize(244,36));
-
-    hbox_percent->setSpacing(10);
-    show_percentage->setDefaultWidget(percent_widget);
-    percent_widget->setStyleSheet("QWidget{background:transparent;border:0px;border-radius:4px}\
-                                  QWidget:hover{background-color:rgba(255,255,255,0.15);}");
-
-    QHBoxLayout *hbox_bright= new QHBoxLayout;
-    QLabel *bright_label = new QLabel(this);
-    QLabel *bright_text = new QLabel(this);
-    QWidget *bright_widget = new QWidget(this);
-    bright_label->setFixedSize(QSize(16,16));
-    bright_label->setPixmap(QPixmap(":/apps/setting.svg"));
-    bright_text->setText(tr("SetBrightness"));
-    bright_label->setStyleSheet("QLabel{background:transparent;border:0px;}");
-    bright_text->setStyleSheet("QLabel{background:transparent;border:0px;}");
-    hbox_bright->addWidget(bright_label);
-    hbox_bright->addWidget(bright_text);
-    bright_widget->setLayout(hbox_bright);
-    bright_widget->setFocusPolicy(Qt::NoFocus);
-    bright_widget->setFixedSize(QSize(244,36));
-    hbox_bright->setSpacing(10);
-    set_bright->setDefaultWidget(bright_widget);
-    bright_widget->setStyleSheet("QWidget{background:transparent;border:0px;border-radius:4px}"
-                                 "QWidget:hover{background-color:rgba(255,255,255,0.15);}");
-
-    connect(set_preference,&QAction::triggered,this,&MainWindow::set_preference_func);
-    connect(set_bright,&QAction::triggered,this,&MainWindow::set_brightness_func);
-    connect(show_percentage,&QAction::triggered,this,&MainWindow::show_percentage_func);
-    menu->addAction(show_percentage);
-    menu->addSeparator();
-    menu->addAction(set_bright);
-    menu->addSeparator();
-    menu->addAction(set_preference);
 
+    create_menu_item();
     trayIcon->setContextMenu(menu);
-    trayIcon->setToolTip(tr("PowerManager"));
-//    qApp->setStyle(new CustomStyle());
+//    trayIcon->setToolTip(tr("PowerManager"));
+}
+
+void MainWindow::create_menu_item()
+{
+    QAction *pset_preference  = new QAction(menu);
+    QAction *pset_bright = new QAction(menu);
+
+    QIcon icon = QIcon::fromTheme("document-page-setup");
+    pset_preference->setIcon(icon);
+    pset_preference->setText(tr("SetPower"));
+
+    pset_bright->setIcon(icon);
+    pset_bright->setText(tr("SetBrightness"));
+
+    connect(pset_preference,&QAction::triggered,this,&MainWindow::set_preference_func);
+    connect(pset_bright,&QAction::triggered,this,&MainWindow::set_brightness_func);
+    menu->addAction(pset_bright);
+    menu->addAction(pset_preference);
 }
 
 int MainWindow::get_engine_dev_number()
@@ -557,46 +500,16 @@ void MainWindow::get_power_list()
         dv = ed->devices.at(i);
         if(dv->m_dev.kind == UP_DEVICE_KIND_LINE_POWER)
             continue;
-        /*QString icon_name = ed->engine_get_device_icon(dv);
-        QString percentage = QString::number(dv->m_dev.Percentage, 'f',0)+"%";
-        bool is_charging = false;
-        QString text;
-        if(icon_name.contains("charging"))
-            is_charging = true;
-        if (is_charging)
-        {
-            text = QString("%1% available power").arg(percentage);
-            text.append("\n");
-            text.append("(The power is connected and is charging)");
-        }
-        else
-            text = QString("%1% available power").arg(percentage);*/
-
 
         DeviceForm *df = new DeviceForm(this);
         df->set_device(dv);
         QListWidgetItem *list_item = new QListWidgetItem(ui->listWidget);
+        list_item->setFlags(Qt::NoItemFlags);
         list_item->setSizeHint(QSize(324,82));
         ui->listWidget->setItemWidget(list_item,df);
+        device_item_map.insert(dv,list_item);
     }
 
-//    for(int i = 0; i < 2; i++)
-//    {
-//        QString icon_name = "gpm-battery-080-charging.png";
-//        QString percentage = QString::number(92.0, 'f',0)+"%";
-//        QString state_text = "charging";
-//        QString predict = "1 hour 5 minutes";
-//        DeviceForm *df= new DeviceForm(this);
-//        df->setIcon(icon_name);
-//        df->setPercent(percentage);
-//        df->slider_changed(int(40));
-//        df->setKind(state_text);
-//        df->setRemain(predict);
-//        QListWidgetItem *list_item = new QListWidgetItem(ui->listWidget);
-//        list_item->setSizeHint(QSize(324,82));
-//        ui->listWidget->setItemWidget(list_item,df);
-//    }
-
 }
 
 void MainWindow::add_one_device(DEVICE *device)
@@ -605,6 +518,7 @@ void MainWindow::add_one_device(DEVICE *device)
     df->set_device(device);
     QListWidgetItem *list_item = new QListWidgetItem(ui->listWidget);
     list_item->setSizeHint(QSize(324,82));
+    list_item->setFlags(Qt::NoItemFlags);
     ui->listWidget->setItemWidget(list_item,df);
     device_item_map.insert(device,list_item);
     dev_number ++;
@@ -614,7 +528,7 @@ void MainWindow::add_one_device(DEVICE *device)
     }
     else
     {
-        resize(360,72 + 8 + 82*dev_number);
+        resize(360,76 + 8 + 82*dev_number);
         ui->listWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
         move(pos().x(),pos().y()-82);
     }
@@ -623,7 +537,6 @@ void MainWindow::add_one_device(DEVICE *device)
 
 void MainWindow::remove_one_device(DEVICE *device)
 {
-
     if(device_item_map.contains(device))
     {
         QListWidgetItem *del_item = device_item_map.value(device);
@@ -635,7 +548,10 @@ void MainWindow::remove_one_device(DEVICE *device)
             df->deleteLater();
         //erase map
         device_item_map.remove(device);
+        device->deleteLater();
+        device = NULL;
         delete del_item;
+        del_item = NULL;
         dev_number --;
         if(dev_number > 3)
         {
@@ -646,7 +562,7 @@ void MainWindow::remove_one_device(DEVICE *device)
             ui->listWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
             if(dev_number < 3)
             {
-                resize(360,72 + 8 + 82*dev_number);
+                resize(360,76 + 8 + 82*dev_number);
                 move(pos().x(),pos().y()+82);
             }
         }
@@ -662,8 +578,6 @@ void MainWindow::activate_power_statistic()
 void MainWindow::iconThemeChanged()
 {
     qDebug()<<"icon theme changed";
-//    QVariant var = setting->get(POWER_SCHEMA_KEY);
-//    QString value = var.value<QString>();
 }
 
 bool MainWindow::event(QEvent *event)
@@ -676,14 +590,28 @@ bool MainWindow::event(QEvent *event)
     return QWidget::event(event);
 }
 
+//bool MainWindow::eventFilter(QObject *watched, QEvent *event)
+//{
+//    if(QEvent::WindowDeactivate == event->type())
+//    {
+//        hide();
+//        return true;
+//    }
+//    else
+//        return QWidget::eventFilter(watched,event);
+//}
+
 void MainWindow::paintEvent(QPaintEvent *event)
 {
+//    transparent = get_window_opacity();
     QPainter p(this);
+    QStyleOption opt;
+    opt.init(this);
+    p.setBrush(opt.palette.color(QPalette::Base));
     p.setPen(Qt::NoPen);
-    QPainterPath path;
-    path.addRoundedRect(rect(),6,6);
+    p.setOpacity(transparent);
     p.setRenderHint(QPainter::Antialiasing);
-    setProperty("blurRegion",QRegion(path.toFillPolygon().toPolygon()));
+    p.drawRoundedRect(rect(),6,6);
     QWidget::paintEvent(event);
 }
 
@@ -713,3 +641,44 @@ int MainWindow::getTaskbarHeight(QString str)
     return reply;
 }
 
+double MainWindow::get_window_opacity()
+{
+    double t = 0.7;
+    if (QGSettings::isSchemaInstalled("org.ukui.control-center.personalise"))
+    {
+
+        QGSettings settings("org.ukui.control-center.personalise");
+        QStringList keys = settings.keys();
+        if(keys.contains("transparency")){
+           t = settings.get("transparency").toDouble();
+        }
+    }
+    return t;
+}
+
+QString MainWindow::get_window_style()
+{
+    style_nm = "ukui-dark";
+    if (QGSettings::isSchemaInstalled(GPM_SETTINGS_SCHEMA_STYLE))
+    {
+        style_set = new QGSettings(GPM_SETTINGS_SCHEMA_STYLE);
+        connect(style_set,SIGNAL(changed(const QString&)),this,SLOT(style_name_settings_cb(const QString&)));
+
+        QStringList keys = style_set->keys();
+        if(keys.contains(GPM_SETTINGS_STYLE_NAME)){
+           style_nm = style_set->get(GPM_SETTINGS_STYLE_NAME).toString();
+        }
+    }
+    return style_nm;
+}
+
+void MainWindow::style_name_settings_cb(const QString&)
+{
+    QVariant var =style_set->get(GPM_SETTINGS_STYLE_NAME);
+    style_nm = var.value<QString>();
+    Q_EMIT style_modify(style_nm);
+//    if(style_nm == "ukui-dark")
+//        ;
+//    else if(style_nm == "ukui-white")
+//        ;
+}
