@@ -21,7 +21,7 @@
 #include "ukpm_widget.h"
 #include <QCommandLineOption>
 #include <QCommandLineParser>
-
+#include <X11/Xlib.h>
 
 int main(int argc, char *argv[])
 {
@@ -30,19 +30,51 @@ int main(int argc, char *argv[])
     {
         return 0;
     }
-    QApplication a(argc, argv);
 
+    Display *display = XOpenDisplay(NULL);
+    if (NULL == display) {
+    qDebug() << "Can't open display!";
+    return -1;
+    }
+    Screen *screen = DefaultScreenOfDisplay(display);
+    if (NULL == screen) {
+    qDebug() << "Get default screen failed!";
+        return -1;
+    }
+    int width = screen->width;
+
+    if (width > 2560) {
+        #if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
+                QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+                QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+        #endif
+    }
+
+    XCloseDisplay(display);
+
+    QApplication a(argc, argv);
     QCommandLineParser parser;
     QCommandLineOption op("device","device","device","");
     parser.addOption(op);
     parser.parse(a.arguments());
     QString device = parser.value(op);
-    QString locale = QLocale::system().name();
+//    QString locale = QLocale::system().name();
+//    QTranslator translator;
+//    QString qmfile = QString(":/locale/%1.qm").arg(locale);
+//    if(locale == "zh_CN")
+//    {
+//        translator.load(qmfile);
+//        a.installTranslator(&translator);
+//    }
     QTranslator translator;
-    QString qmfile = QString(":/locale/%1.qm").arg(locale);
-    translator.load(qmfile);
-    a.installTranslator(&translator);
-    a.setWindowIcon(QIcon(":/resource/icon/ukui-power-statistics.png"));
+    if (translator.load(QLocale(),"ukui-power-statistics","_",QM_FILES_INSTALL_PATH))
+        a.installTranslator(&translator);
+    else
+        qDebug()<<"load ukui-power-manager-statistics qm file error";
+
+    QIcon icon = QIcon::fromTheme("ukui-power-statistics");
+    a.setWindowIcon(icon);
+//    a.setWindowIcon(QIcon(":/resource/icon/ukui-power-statistics.png"));
     UkpmWidget *w = new UkpmWidget;
     if(!device.isEmpty())
     {
