@@ -19,6 +19,10 @@
 #include "customtype.h"
 #include "sys/time.h"
 #include <float.h>
+#include <QGraphicsDropShadowEffect>
+#include <QtMath>
+#include <QStyleFactory>
+#include <QPainterPath>
 
 #define GPM_HISTORY_RATE_TEXT			"Rate"
 #define GPM_HISTORY_CHARGE_TEXT			"Charge"
@@ -272,9 +276,17 @@ void UkpmWidget::getDevices()
 
             if(kindEnum == UP_DEVICE_KIND_LINE_POWER || kindEnum == UP_DEVICE_KIND_BATTERY || kindEnum == UP_DEVICE_KIND_COMPUTER)
             {
-                item = new QListWidgetItem(QIcon(":/resource/icon/"+icon+".png"),label);
+                DeviceWidget *dw = new DeviceWidget;
+                dw->setAttribute(Qt::WA_DeleteOnClose);
+                dw->set_device_icon(":/resource/icon/"+icon+".png");
+                dw->set_device_text(false,label);
+//                item = new QListWidgetItem(QIcon(":/resource/icon/"+icon+".png"),label);
+                item = new QListWidgetItem;
+                item->setSizeHint(QSize(150,36));
+                dw->setFixedSize(item->sizeHint());
                 listItem.insert(deviceNames.at(i),item);
                 listWidget->addItem(item);
+                listWidget->setItemWidget(item,dw);
             }
             else
                 return;
@@ -452,7 +464,8 @@ ukpm_update_info_page_details (DEV* device)
     model->clear();
     QStringList header;
     header << tr("Attribute") << tr("Value");
-    model->setHorizontalHeaderLabels(header);
+//    model->setHorizontalHeaderLabels(header);
+    addListRow(tr("Attribute"),tr("Value"));
 
     addListRow(tr("Device"),device_path);
     /* TRANSLATORS: the device ID of the current device, e.g. "battery0" */
@@ -559,7 +572,7 @@ void UkpmWidget::ukpm_update_info_data (DEV* device)
     if (has_history)
     {
         if(index == -1)
-            tab_widget->addTab(his_widget,tr("history"));
+            tab_widget->addTab(his_widget,tr(" history "));
     }
     else
     {
@@ -570,7 +583,7 @@ void UkpmWidget::ukpm_update_info_data (DEV* device)
     if (has_statistics)
     {
         if(-1 == index)
-            tab_widget->addTab(stat_widget,tr("statistics"));
+            tab_widget->addTab(stat_widget,tr(" statistics "));
     }
     else
     {
@@ -1080,7 +1093,7 @@ void UkpmWidget::draw_history_graph(QString type)
         else
         {
             starty = 0;
-            stopy = 60*60*6;
+            stopy = 60*10;
         }
 
         axisY->setMin(starty);
@@ -1124,7 +1137,7 @@ void UkpmWidget::draw_history_graph(QString type)
         else
         {
             starty = 0;
-            stopy = 60*60*6;
+            stopy = 60*10;
         }
 
 
@@ -1246,18 +1259,17 @@ void UkpmWidget::ukpm_update_info_page_stats (DEV* device)
 
 void UkpmWidget::setSumTab()
 {
-    stat_widget = new QWidget(this);
+    stat_widget = new QWidget();
     QLabel *graphicType = new QLabel(tr("graphic type:"),stat_widget);
     graphicType->setObjectName("m_sumGraphicType");
     sumTypeCombox = new QComboBox(stat_widget);
     sumTypeCombox->addItems(QStringList()<<tr("charge")<<tr("charge-accurency")<<tr("discharge")<<tr("discharge-accurency"));
 
     QListView * listView = new QListView(sumTypeCombox);
-    listView->setStyleSheet("QListView::item:selected {background: #EDEDED }");
     sumTypeCombox->setView(listView);
 
     sum_line_btn = new QPushButton(tr("show line"),stat_widget);
-    sum_data_btn = new QPushButton(tr("show data points"),stat_widget);
+    sum_data_btn = new QPushButton(tr("show points"),stat_widget);
     sum_line_btn->setObjectName("sum_line_btn");
     sum_data_btn->setObjectName("sum_data_btn");
     sum_line_btn->setFixedSize(100,32);
@@ -1272,9 +1284,9 @@ void UkpmWidget::setSumTab()
     QHBoxLayout *bottomLayout = new QHBoxLayout;
     QFormLayout *topFormLayout = new QFormLayout;
 
-    graphicType->setFixedHeight(30);
+    graphicType->setFixedHeight(36);
     sumTypeCombox->setFixedWidth(200);
-    sumTypeCombox->setFixedHeight(30);
+    sumTypeCombox->setFixedHeight(36);
     topFormLayout->addRow(graphicType,sumTypeCombox);
     topFormLayout->setSpacing(0);
     topFormLayout->setContentsMargins(0,0,0,0);
@@ -1294,7 +1306,7 @@ void UkpmWidget::setSumTab()
     sumChart->setAxisX(x);
     sumChart->setAxisY(y);
 
-    QFont font("Times");
+    QFont font = x->labelsFont();
     font.setPixelSize(12);
     x->setLabelsFont(font);
     y->setLabelsFont(font);
@@ -1325,13 +1337,6 @@ void UkpmWidget::setSumTab()
 
     QVBoxLayout *vLayout = new QVBoxLayout;
 
-//    sumStack = new QStackedWidget;
-//    QLabel *nodata = new QLabel;
-//    nodata->setText(tr("no data to show."));
-//    nodata->setAlignment(Qt::AlignCenter);
-//    sumStack->addWidget(nodata);
-//    sumStack->addWidget(sumChartView);
-
     vLayout->addLayout(topFormLayout);
     vLayout->addWidget(sumChartView);
     vLayout->addLayout(bottomLayout);
@@ -1387,35 +1392,40 @@ void UkpmWidget::showSumDataPoint(bool flag)
 
 void UkpmWidget::setDetailTab()
 {
-    detail_widget = new QWidget(this);
-    tab_widget->addTab(detail_widget,tr("detail"));
+    detail_widget = new QWidget();
+    tab_widget->addTab(detail_widget,tr(" detail "));
 
     tableView  = new QTableView();
-    tableView->horizontalHeader()->setStretchLastSection(true);
-    tableView->horizontalHeader()->setDefaultAlignment(Qt::AlignLeft);
-    tableView->verticalHeader()->hide();
+    model = new QStandardItemModel();
+    tableView->setModel(model);
+    tableView->setFocusPolicy(Qt::NoFocus);
     //背景网格线设置
     //显示
     tableView->setShowGrid(false);
     //网格背景画笔
-    //ui->tableView->setGridStyle(Qt::DashLine);
     tableView->setGridStyle(Qt::DotLine);
-    //排序功能
-    tableView->setSortingEnabled(true);
     tableView->setEditTriggers(QAbstractItemView::NoEditTriggers);
     tableView->setSelectionMode(QAbstractItemView::NoSelection);
-    model = new QStandardItemModel();
 
-    tableView->setModel(model);
+    tableView->horizontalHeader()->setSectionResizeMode(QHeaderView::Fixed);
+    tableView->setColumnWidth(0,100);
+    tableView->horizontalHeader()->setStretchLastSection(true);
+    tableView->horizontalHeader()->hide();
+
+    tableView->verticalHeader()->setMinimumSectionSize(0);
+    tableView->verticalHeader()->setDefaultSectionSize(26);
+    tableView->verticalHeader()->setSectionResizeMode(QHeaderView::Fixed);
+    tableView->verticalHeader()->hide();
+
     QVBoxLayout *lay = new QVBoxLayout();
+    lay->setContentsMargins(0,15,0,0);
     lay->addWidget(tableView);
     detail_widget->setLayout(lay);
-//    detail_widget->hide();
 }
 
 void UkpmWidget::setHistoryTab()
 {
-    his_widget = new QWidget(this);
+    his_widget = new QWidget();
     QLabel *graphicType = new QLabel(tr("graphic type:"),his_widget);
     graphicType->setScaledContents(true);
     QLabel *timeLabel = new QLabel(tr("time span:"),his_widget);
@@ -1427,20 +1437,18 @@ void UkpmWidget::setHistoryTab()
     typeCombox->setObjectName("m_typeCombox");
     spanCombox = new QComboBox(his_widget);
     spanCombox->addItems(QStringList()<<tr("ten minutes")<<tr("two hours")<<tr("six hours")<<tr("one day")<<tr("one week"));
-    graphicType->setFixedHeight(30);
-    timeLabel->setFixedHeight(30);
-    typeCombox->setFixedHeight(30);
-    spanCombox->setFixedHeight(30);
+    graphicType->setFixedHeight(36);
+    timeLabel->setFixedHeight(36);
+    typeCombox->setFixedHeight(36);
+    spanCombox->setFixedHeight(36);
 
     QListView * typeView = new QListView(typeCombox);
-    typeView->setStyleSheet("QListView::item:selected {background: #EDEDED }");
     typeCombox->setView(typeView);
     QListView * spanView = new QListView(spanCombox);
-    spanView->setStyleSheet("QListView::item:selected {background: #EDEDED }");
     spanCombox->setView(spanView);
 
     his_line_btn = new QPushButton(tr("show line"),his_widget);
-    his_data_btn = new QPushButton(tr("show data points"),his_widget);
+    his_data_btn = new QPushButton(tr("show points"),his_widget);
     his_line_btn->setObjectName("his_line_btn");
     his_data_btn->setObjectName("his_data_btn");
     his_line_btn->setFixedSize(100,32);
@@ -1487,7 +1495,7 @@ void UkpmWidget::setHistoryTab()
     axisY = new QCategoryAxis();
     xtime->setTitleText(tr("elapsed time"));
     xtime->setReverse(true);
-    QFont font("Times");
+    QFont font = xtime->labelsFont();
     font.setPixelSize(12);
     xtime->setLabelsFont(font);
     axisY->setLabelsFont(font);
@@ -1505,26 +1513,19 @@ void UkpmWidget::setHistoryTab()
 
     hisChart->setPlotAreaBackgroundBrush(plotcolor);
     hisChart->setPlotAreaBackgroundVisible(true);
-//    hisChart->setPlotAreaBackgroundPen(QPen(QColor("#2f3032"),1));
     hisChartView = new QChartView(hisChart);
     hisChartView->setRenderHint(QPainter::Antialiasing);
     hisChartView->setContentsMargins(0,0,0,0);
     hisChart->setContentsMargins(0,20,0,0);
     hisChart->setMargins(QMargins(0,0,0,0));
     QVBoxLayout *vLayout = new QVBoxLayout;
-//    hisStack = new QStackedWidget;
-//    QLabel *nodata = new QLabel;
-//    nodata->setText(tr("no data to show."));
-//    nodata->setAlignment(Qt::AlignCenter);
-//    hisStack->addWidget(nodata);
-//    hisStack->addWidget(hisChartView);
+
     vLayout->setSpacing(0);
     vLayout->addLayout(topLayout);
     vLayout->addWidget(hisChartView);
     vLayout->addLayout(bottomLayout);
     vLayout->setContentsMargins(0,20,0,32);
     his_widget->setLayout(vLayout);
-//    tab_widget->addTab(his_widget,tr("history"));
     his_widget->hide();
     ukpm_set_choice_history();
 }
@@ -1612,14 +1613,16 @@ QString UkpmWidget::getWidgetAxis(uint value)
         if(hours ==0)
             text.sprintf("%dd",days);
         else
-            text.sprintf("%dd%dh",days,hours);
+//            text.sprintf("%dd%dh",days,hours);
+            text.sprintf("%.1fd",days+hours*1.0/24);
     }
     else if(hours > 0)
     {
         if(minutes ==0)
             text.sprintf("%dh",hours);
         else
-            text.sprintf("%dh%dm",hours,minutes);
+//            text.sprintf("%dh%dm",hours,minutes);
+            text.sprintf("%.1fh",(hours+minutes*1.0/60));
     }
     else if(minutes > 0)
     {
@@ -1658,19 +1661,26 @@ void UkpmWidget::onitemSelectionChanged()
         auto iterator = dev_item.find(tmp);
         if(iterator != dev_item.end())
         {
+            QWidget *wid = listWidget->itemWidget(tmp);
+            DeviceWidget *dw = qobject_cast<DeviceWidget*>(wid);
+
             DEVICE *device = dev_item.value(tmp);
             QString icon = up_device_kind_to_string(device->m_dev->kind);
             if(tmp != cur)
             {
                 icon = ":/resource/icon/" + icon + ".png";
+                dw->set_device_icon(icon);
+                dw->set_device_text(false);
             }
             else
             {
                 icon = ":/resource/icon/" + icon + "w" + ".png";
+                dw->set_device_text(true);
+                dw->set_device_icon(icon);
+
                 current_device = device->m_dev;
                 ukpm_update_info_data(current_device);
             }
-            tmp->setIcon(QIcon(icon));
         }
     }
 
@@ -2047,35 +2057,45 @@ void UkpmWidget::setupUI()
 
     setWindowFlags(Qt::FramelessWindowHint);
     setAttribute(Qt::WA_TranslucentBackground);
-    QSplitter *mainsplitter = new QSplitter(Qt::Horizontal,this);//splittering into two parts
+
+    QFrame *frame = new QFrame(this);
+    frame->setObjectName("main_frame");
+    frame->setStyleSheet("QFrame#main_frame{background-color: white;border-radius:6px;border:1px solid #c2c3c8;}"); //设置圆角与背景透明
+
+    QSplitter *mainsplitter = new QSplitter(Qt::Horizontal);//splittering into two parts
+    QHBoxLayout *deviceLay = new QHBoxLayout;
+    deviceLay->setContentsMargins(0,0,40,0);
+    deviceLay->setSpacing(40);
     listWidget = new QListWidget(mainsplitter);
     listWidget->setObjectName("m_listWidget");
     listWidget->setFixedWidth(180);
-//    listWidget->setSpacing(10);
-    tab_widget =  new QTabWidget(mainsplitter);
-//    tab_widget->setFixedWidth(600);
-//    QList<int> list_src;
-//    list_src.append(180);
-//    list_src.append(600);
-//    mainsplitter->setSizes(list_src);
-//    mainsplitter->handle(1)->setDisabled(true);
+    listWidget->setSpacing(8);
+    listWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+    deviceLay->addWidget(listWidget);
+    tab_widget =  new QTabWidget(this);
+    tab_widget->setStyle(QStyleFactory::create("fusion"));
+    deviceLay->addWidget(tab_widget);
+
     QVBoxLayout *vlayout = new QVBoxLayout;
-    QFrame *header = new QFrame(this);
+    QFrame *header = new QFrame(frame);
     header->setFixedHeight(TITLE_HEIGHT+30);
+
     QLabel *header_head = new QLabel(header);
-    header_head->setGeometry(0,0,180,62);
+    header_head->setGeometry(0,0,180,TITLE_HEIGHT+30);
     header_head->setStyleSheet("background-color:#F7F7F7;");
     header->setWindowFlags(Qt::FramelessWindowHint);
     header->setStyleSheet("QFrame{padding-bottom:30px;background-color:white;border-top-right-radius:6px;"
                           "border-top-left-radius:6px;border-bottom-right-radius:0px;border-bottom-left-radius:0px;}");
-    mainsplitter->setStyleSheet("QSplitter{ background-color:white;border-top-right-radius:0px;"
-                          "border-top-left-radius:0px;border-bottom-right-radius:6px;border-bottom-left-radius:6px;}");
+
     vlayout->addWidget(header);
-    vlayout->addWidget(mainsplitter);
+    vlayout->addLayout(deviceLay);
     vlayout->setSpacing(0);
     vlayout->setContentsMargins(0,0,0,0);
-//    this->setStyleSheet("QWidget {background:white}");
-    setLayout(vlayout);//main layout of the UI
+    frame->setLayout(vlayout);//main layout of the UI
+    QVBoxLayout *mainlay = new QVBoxLayout;
+    mainlay->setContentsMargins(0,0,0,0);
+    this->setLayout(mainlay);
+    mainlay->addWidget(frame);
     title = new TitleWidget(this);
     title->move(0,0);
 
@@ -2094,9 +2114,22 @@ void UkpmWidget::setupUI()
 
         QString icon = up_device_kind_to_string(current_device->kind);
         icon = ":/resource/icon/" + icon + "w" + ".png";
-        default_item->setIcon(QIcon(icon));
+        QWidget *wid = listWidget->itemWidget(default_item);
+        DeviceWidget *dw = qobject_cast<DeviceWidget *>(wid);
+        dw->set_device_icon(icon);
+        dw->set_device_text(true);
         ukpm_update_info_data (current_device);
     }
 
 }
 
+void UkpmWidget::paintEvent(QPaintEvent *event)
+{
+    QPainter p(this);
+    p.setPen(Qt::NoPen);
+    QPainterPath path;
+    path.addRoundedRect(rect(),6,6);
+    p.setRenderHint(QPainter::Antialiasing);
+    setProperty("blurRegion",QRegion(path.toFillPolygon().toPolygon()));
+    QWidget::paintEvent(event);
+}
